@@ -1,15 +1,15 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Tests for idaes.commands
 """
@@ -20,7 +20,7 @@ import os
 from pathlib import Path
 from shutil import rmtree
 import subprocess
-import time
+import sys
 from typing import Union
 import uuid
 
@@ -29,13 +29,17 @@ from click.testing import CliRunner
 import pytest
 
 # package
-from idaes.commands import examples
+from idaes.commands import examples, extensions, convergence, config, env_info
 from idaes.util.system import TemporaryDirectory
 from . import create_module_scratch, rmtree_scratch
+import idaes
 
 __author__ = "Dan Gunter"
 
+
 _log = logging.getLogger(__name__)
+if os.environ.get("IDAES_TEST_DEBUG", False):
+    _log.setLevel(logging.DEBUG)
 
 
 @pytest.fixture(scope="module")
@@ -86,30 +90,57 @@ def test_examples_cli_list(runner):
     assert result.exit_code == 0
 
 
+def can_write(path):
+    """Test ability to write a file in 'path'.
+    Assume the path is a temporary directory, so don't bother cleaning up.
+    """
+    if not path.exists():
+        _log.debug(f"can_write: Creating parent directory '{path}'")
+        try:
+            path.mkdir()
+        except Exception as err:
+            _log.warning(f"Failed to create temporary directory '{path}': {err}")
+            return False
+    test_file = path / "test_file.txt"
+    _log.debug(f"can_write: Creating file '{test_file}'")
+    try:
+        fp = test_file.open("w")
+        fp.write("hello")
+        fp.close()
+    except Exception as err:
+        _log.warning(f"Failed to write sample file '{test_file}': {err}")
+        return False
+
+
 @pytest.mark.integration()
 def test_examples_cli_download(runner, tempdir):
     # failure with existing dir
     result = runner.invoke(examples.get_examples, ["-d", str(tempdir), "-I"])
     assert result.exit_code == -1
-    # pick subdir, should be ok; use old version we know exists
+
+
+@pytest.mark.integration()
+def test_examples_cli_explicit_version(runner, tempdir):
     dirname = str(tempdir / "examples")
     result = runner.invoke(examples.get_examples, ["-d", dirname, "-I", "-V", "1.5.0"])
     assert result.exit_code == 0
 
 
+@pytest.mark.skip("Erroneously fails when latest ideas version is a pre-release")
 @pytest.mark.integration()
 def test_examples_cli_default_version(runner, tempdir):
     dirname = str(tempdir / "examples")
     result = runner.invoke(examples.get_examples, ["-d", dirname])
-    assert result.exit_code == -1
+    assert result.exit_code == 0
 
 
 @pytest.mark.integration()
 def test_examples_cli_download_unstable(runner, tempdir):
-    dirname = str(tempdir / "examples")
-    # unstable version but no --unstable flag
-    result = runner.invoke(examples.get_examples, ["-d", dirname, "-V", "1.2.3-beta"])
-    assert result.exit_code == -1
+    if can_write(tempdir):
+        dirname = str(tempdir / "examples")
+        # unstable version but no --unstable flag
+        result = runner.invoke(examples.get_examples, ["-d", dirname, "-V", "1.2.3-beta"])
+        assert result.exit_code == -1
 
 
 @pytest.mark.integration()
@@ -121,7 +152,7 @@ def test_examples_cli_copy(runner, tempdir):
     assert result.exit_code == -1
     # local dir exists, no REPO_DIR in it
     src_dir = tempdir / "examples-dev"
-    src_dir.mkdir()
+    src_dir.mkdir(exist_ok=True)
     result = runner.invoke(
         examples.get_examples, ["-d", dirname, "--local", str(src_dir), "-I"]
     )
@@ -146,7 +177,7 @@ def test_examples_cli_copy(runner, tempdir):
 def test_examples_n():
     target_dir = str(uuid.uuid4())  # pick something that won't exist
     retcode = subprocess.call(["idaes", "get-examples", "-N", "-d", target_dir])
-    assert retcode == 255  # result of sys.exit(-1)
+    assert retcode != 0  # failure
 
 
 @pytest.mark.integration()  # goes out to network
@@ -217,21 +248,23 @@ def test_examples_check_github_response():
     )
 
 
+@pytest.mark.nowin32
 @pytest.mark.integration
-def test_examples_install_src(tempdir):
+def test_examples_install_src():
+    tempdir = create_module_scratch("examples_install_src")
     # monkey patch a random install package name so as not to have
     # any weird side-effects on other tests
     orig_install_pkg = examples.INSTALL_PKG
     examples.INSTALL_PKG = "i" + str(uuid.uuid4()).replace("-", "_")
-    # print(f"1. curdir={os.curdir}")
+    _log.debug(f"install_src: curdir={os.curdir}")
     # create fake package
     src_dir = tempdir / "src"
-    src_dir.mkdir()
+    src_dir.mkdir(exist_ok=True)
     m1_dir = src_dir / "module1"
-    m1_dir.mkdir()
+    m1_dir.mkdir(exist_ok=True)
     (m1_dir / "groot.py").open("w").write("print('I am groot')\n")
     m2_dir = m1_dir / "module1_1"
-    m2_dir.mkdir()
+    m2_dir.mkdir(exist_ok=True)
     (m2_dir / "groot.py").open("w").write("print('I am groot')\n")
     # install it
     examples.install_src("0.0.0", src_dir)
@@ -326,35 +359,6 @@ def test_examples_cleanup_nodist_noegg(tempdir):
     assert not tempsubdir.exists()
 
 
-@pytest.mark.unit
-def test_examples_cleanup_nothing(tempdir):
-    tempdir = tempdir
-    # nothing to remove, should still be ok
-    os.chdir(tempdir)
-    examples.clean_up_temporary_files()
-    # if we set some globals to bogus values, still OK
-    examples.g_egg = Path("no-such-file.egg-info")
-    examples.g_tempdir = Path("no-such-file-tempdir")
-    examples.clean_up_temporary_files()
-    # if we create files and set perms to 000, still OK
-    eggy = Path("egg")
-    eggy.mkdir()
-    eggy.chmod(0)
-    examples.g_egg = eggy
-    subdir = Path("subdirinho")
-    subdir.mkdir()
-    subdir.chmod(0)
-    examples.g_tempdir = subdir
-    dist = Path("dist")
-    dist.mkdir()
-    # dist.chmod(0) -- no, this messes up Windows
-    examples.clean_up_temporary_files()
-    # tempdir will clean up these files:
-    # dist.chmod(700) - removed with .rmdir() which works regardless!
-    eggy.chmod(0o777)
-    subdir.chmod(0o777)
-
-
 @pytest.mark.unit
 def test_examples_local(tempdir):
     d = tempdir
@@ -522,3 +526,157 @@ def test_strip_test_cells(remove_cells_notebooks):
                         n += 1
                 assert n > 0  # tag still there
 
+
+##################
+# get-extensions #
+##################
+
+
+@pytest.mark.unit
+def test_get_extensions(runner):
+    result = runner.invoke(extensions.get_extensions, ["--no-download"])
+    assert result.exit_code == 0
+
+
+@pytest.mark.unit
+def test_print_extensions_version(runner):
+    result = runner.invoke(extensions.get_extensions, ["--show-current-version"])
+    assert result.exit_code == 0
+
+
+@pytest.mark.unit
+def test_print_extensions_version(runner):
+    result = runner.invoke(extensions.get_extensions, ["--show-platforms"])
+    assert result.exit_code == 0
+
+#################
+# convergence  #
+################
+
+@pytest.mark.unit
+def test_conv_search(runner):
+    result = runner.invoke(convergence.convergence_search)
+    assert result.exit_code == 0
+
+
+@pytest.mark.unit
+def test_conv_sample(runner):
+    fname = os.path.join(idaes.testing_directory, "sample.json")
+    result = runner.invoke(
+        convergence.convergence_sample,
+        [
+            "-e",
+            "PressureChanger",
+            "-N",
+            "10",
+            "-s",
+            fname,
+        ])
+    assert result.exit_code == 0
+    if os.path.exists(fname):
+        os.remove(fname)
+
+@pytest.mark.integration
+def test_conv_eval(runner):
+    fname = os.path.join(idaes.testing_directory, "sample.json")
+    fname2 = os.path.join(idaes.testing_directory, "result.json")
+    result = runner.invoke(
+        convergence.convergence_sample,
+        [
+            "-e",
+            "PressureChanger",
+            "-N",
+            "10",
+            "-s",
+            fname,
+        ])
+    assert result.exit_code == 0
+    result = runner.invoke(
+        convergence.convergence_eval,
+        [
+            "-s",
+            fname,
+            "-j",
+            fname2
+        ])
+    assert result.exit_code == 0
+    with open(fname2, "r") as f:
+        d = json.load(f)
+    assert "inputs" in d
+    assert len(d["time_successful"]) == 10
+    if os.path.exists(fname):
+        os.remove(fname)
+    if os.path.exists(fname2):
+        os.remove(fname2)
+
+@pytest.mark.unit
+def test_conf_display(runner):
+    result = runner.invoke(config.config_display)
+    assert result.exit_code == 0
+
+@pytest.mark.unit
+def test_conf_file_paths(runner):
+    result = runner.invoke(config.config_file)
+    assert result.exit_code == 0
+    result = runner.invoke(config.config_file, ["--global"])
+    assert result.exit_code == 0
+    result = runner.invoke(config.config_file, ["--local"])
+    assert result.exit_code == 0
+
+@pytest.mark.unit
+def test_conf_file_paths(runner):
+    fname = os.path.join(idaes.testing_directory, "conf_test.json")
+    result = runner.invoke(config.config_write, ["--file", fname])
+    assert result.exit_code == 0
+    with open(fname, "r") as f:
+        d = json.load(f)
+        assert d["logger_capture_solver"] == True
+    if os.path.exists(fname):
+        os.remove(fname)
+
+@pytest.mark.unit
+def test_conf_set(runner):
+    fname = os.path.join(idaes.testing_directory, "conf_test.json")
+    def _tst(args):
+        result = runner.invoke(config.config_set, [
+            "logging:loggers:idaes.solver:handlers", "['console']"] + args)
+        assert result.exit_code == 0
+        with open(fname, "r") as f:
+            d = json.load(f)
+            assert len(d["logging"]["loggers"]["idaes.solver"]["handlers"]) == 1
+            assert d["logging"]["loggers"]["idaes.solver"]["handlers"][0] == 'console'
+        result = runner.invoke(config.config_set, [
+            "logging:loggers:idaes.solver:handlers", "'console'", "--del"] + args)
+        assert result.exit_code == 0
+        result = runner.invoke(config.config_set, [
+            "logging:loggers:idaes.solver:handlers", "'console'", "--add"] + args)
+        assert result.exit_code == 0
+        with open(fname, "r") as f:
+            d = json.load(f)
+            assert len(d["logging"]["loggers"]["idaes.solver"]["handlers"]) == 1
+            assert d["logging"]["loggers"]["idaes.solver"]["handlers"][0] == 'console'
+        result = runner.invoke(config.config_set, [
+            "ipopt_l1:options:max_iter", "100"] + args)
+        assert result.exit_code == 0
+        assert "ConfigDict" in str(type(idaes.cfg.ipopt_l1))
+        assert "ConfigDict" in str(type(idaes.cfg.ipopt_l1.options))
+        assert idaes.cfg.ipopt_l1.options.max_iter == 100
+        if os.path.exists(fname):
+            os.remove(fname)
+
+    # lbianchi-lbl: these sets of args seem to fail if tensorflow has been imported (#633)
+    # TODO these could be refactored as a parametrized pytest.fixture
+    if "tensorflow" not in sys.modules:
+        _tst(["--global", "--file", fname, "--file_as_global"])
+        _tst(["--local", "--file", fname, "--file_as_local"])
+    _tst(["--file", fname])
+
+
+##############
+# env info   #
+##############
+
+@pytest.mark.unit
+def test_env_info1(runner):
+    result = runner.invoke(env_info.environment_info)
+    assert result.exit_code == 0
