@@ -1,28 +1,29 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Workspace classes and functions.
 """
 # stdlib
 import logging
 import os
+import re
 from typing import List
+from urllib.parse import urlparse
 import uuid
-import yaml
 
 # third-party
 import jsonschema
-import six
+import yaml
 
 # local
 from .errors import (
@@ -35,7 +36,7 @@ from .errors import (
 )
 from .util import yaml_load
 
-__author__ = 'Dan Gunter <dkgunter@lbl.gov>'
+__author__ = "Dan Gunter <dkgunter@lbl.gov>"
 
 _log = logging.getLogger(__name__)
 
@@ -52,7 +53,7 @@ CONFIG_SCHEMA = {
                 "type": "string",
                 "description": "directory containing Sphinx HTML docs",
             },
-            "default": "{dmf_root}/docs/build/html",
+            "default": "https://idaes-pse.readthedocs.io/en/stable,{dmf_root}/docs/build/html"
         },
         "description": {
             "description": "A human-readable description of the workspace",
@@ -67,8 +68,8 @@ class Fields(object):
     """Workspace configuration fields.
     """
 
-    DOC_HTML_PATH = 'htmldocs'  # path to documentation html dir
-    LOG_CONF = 'logging'  # logging config
+    DOC_HTML_PATH = "htmldocs"  # path to documentation html dir
+    LOG_CONF = "logging"  # logging config
 
 
 class Workspace(object):
@@ -147,22 +148,27 @@ class Workspace(object):
     """
 
     #: Name of configuration file placed in WORKSPACE_DIR
-    WORKSPACE_CONFIG = 'config.yaml'
+    WORKSPACE_CONFIG = "config.yaml"
     #: Name of ID field
-    ID_FIELD = '_id'
+    ID_FIELD = "_id"
 
-    CONF_NAME = 'name'  #: Configuration field for name
-    CONF_DESC = 'description'  #: Configuration field for description
-    CONF_CREATED = 'created'  #: Configuration field for created date
-    CONF_MODIFIED = 'modified'  #: Configuration field for modified date
+    CONF_NAME = "name"  #: Configuration field for name
+    CONF_DESC = "description"  #: Configuration field for description
+    CONF_CREATED = "created"  #: Configuration field for created date
+    CONF_MODIFIED = "modified"  #: Configuration field for modified date
 
-    def __init__(self, path, create=False, add_defaults=False, html_paths=None):
+    def __init__(
+        self, path, create=False, existing_ok=True, add_defaults=False, html_paths=None
+    ):
         """Load or create a workspace rooted at `path`
 
         Args:
             (str) path: Path for root of workspace
             (bool) create: Create the workspace if it does not exist.
-            (bool) add_defaults: Add default values to new config
+            (bool) existing_ok: If create is True, and the workspace exists, just continue
+            (bool) add_defaults: Add default values to new configuration.
+                    These values are found in the JSON Schema that is stored in the module variable
+                    `CONFIG_SCHEMA`, and substituted by logic in :meth:`WorkspaceConfiguration.get_fields`.
             html_paths: One or more paths to HTML docs (or None)
         Raises:
             WorkspaceNotFoundError: if ws is not found (and create is false)
@@ -175,6 +181,7 @@ class Workspace(object):
         self._conf = os.path.join(self._wsdir, self.WORKSPACE_CONFIG)
         self._cached_conf = None
         if create:
+            skip_config = False
             # note: these raise OSError on failure
             try:
                 os.mkdir(self._wsdir, 0o770)
@@ -182,19 +189,24 @@ class Workspace(object):
                 if not os.path.exists(self._wsdir):
                     raise WorkspaceCannotCreateError(self._wsdir)
                 if os.path.exists(self._conf):
+                    if existing_ok:
+                        _log.info(f"Using existing DMF workspace: {self._conf}")
+                        skip_config = True
+                    else:
+                        raise WorkspaceError(
+                            "existing configuration would be "
+                            "overwritten: {}".format(self._conf)
+                        )
+                _log.info(
+                    "Using existing path for new DMF workspace: {}".format(self._wsdir)
+                )
+            if not skip_config:
+                try:
+                    self._create_new_config(add_defaults)
+                except OSError as err:
                     raise WorkspaceError(
-                        'existing configuration would be '
-                        'overwritten: {}'.format(self._conf)
+                        "while creating new workspace " "configuration: {}".format(err)
                     )
-                _log.warning(
-                    'Using existing path for new DMF workspace: {}'.format(self._wsdir)
-                )
-            try:
-                self._create_new_config(add_defaults)
-            except OSError as err:
-                raise WorkspaceError(
-                    'while creating new workspace ' 'configuration: {}'.format(err)
-                )
         else:
             # assert that the workspace exists
             try:
@@ -209,7 +221,7 @@ class Workspace(object):
         try:
             self._id = self.meta[self.ID_FIELD]
         except KeyError:
-            raise WorkspaceConfMissingField(path, self.ID_FIELD, 'ID field')
+            raise WorkspaceConfMissingField(path, self.ID_FIELD, "ID field")
         if html_paths:
             self.set_doc_paths(html_paths)
 
@@ -217,7 +229,7 @@ class Workspace(object):
         _log.info(f"Create new configuration at '{self._conf}'")
         conf = open(self._conf, 'w')  # create the file
         new_id = uuid.uuid4().hex  # create new unique ID
-        conf.write('{}: {}\n'.format(self.ID_FIELD, new_id))  # write ID
+        conf.write("{}: {}\n".format(self.ID_FIELD, new_id))  # write ID
         conf.close()  # flush and close
         if add_defaults:
             self._configure_defaults()
@@ -225,11 +237,13 @@ class Workspace(object):
     def _configure_defaults(self):
         """Add default values to the workspace configuration.
 
+        The default values are provided by the w
+
         Note: this will *overwrite* any existing values!
         """
         values = {
             key: val
-            for key, (desc, val) in WorkspaceConfig()
+            for key, (desc, val) in WorkspaceConfiguration()
             .get_fields(only_defaults=True)
             .items()
         }
@@ -248,7 +262,7 @@ class Workspace(object):
     def _get_install_dir():
         fpath = os.path.realpath(__file__)
         fdir = os.path.dirname(fpath)
-        idir = os.path.join(fdir, '..', '..')
+        idir = os.path.join(fdir, "..", "..")
         return os.path.abspath(idir)
 
     def set_meta(self, values, remove=None):
@@ -302,7 +316,7 @@ class Workspace(object):
             stack = [(k, d) for k in d]
             while stack:
                 key, p = stack.pop()
-                if key == 'output':
+                if key == "output":
                     p[key] = self._expand_path(p[key])
                 elif isinstance(p[key], dict):
                     for key2 in p[key].keys():
@@ -317,7 +331,7 @@ class Workspace(object):
             (list) Paths or empty list if not found.
         """
         paths = self.meta.get(Fields.DOC_HTML_PATH, [])
-        if len(paths) and hasattr(paths, 'lower'):
+        if len(paths) and hasattr(paths, "lower"):
             paths = [paths]  # make a str into a list
         return paths
 
@@ -341,7 +355,7 @@ class Workspace(object):
         #: type (None) -> dict
         if self._cached_conf is None:
             _log.debug('Load workspace configuration from "{}"'.format(self._conf))
-            conf = open(self._conf, 'r')
+            conf = open(self._conf, "r")
             try:
                 contents = yaml_load(conf)
             except Exception as err:
@@ -354,21 +368,28 @@ class Workspace(object):
         else:
             contents = self._cached_conf
         if isinstance(contents, str):
-            raise ParseError('File contents cannot be simple str ({})'.format(contents))
+            raise ParseError("File contents cannot be simple str ({})".format(contents))
         else:
             return contents.copy()
 
     def _expand_path(self, path):
-        # leave paths bracketed by _underscores_ alone
-        if len(path) > 2 and path[0] == '_' and path[-1] == '_':
-            return path
-        return os.path.realpath(
-            path.format(ws_root=self.root, dmf_root=self._install_dir)
-        )
+        # leave paths bracketed by _underscores_ as-is
+        if re.match(r"^_.*_$", path):
+            pass
+        else:
+            # See if this is a file or web URL.
+            # Do substitution on file paths, but leave web URLs alone.
+            parsed = urlparse(path)
+            if (not parsed.netloc) and parsed.path:
+                # Do substitution of '{ws_root}' and '{dmf_root}' in the path
+                path = os.path.realpath(
+                    path.format(ws_root=self.root, dmf_root=self._install_dir)
+                )
+        return path
 
     def _write_conf(self, contents):
         #: type (dict) -> None
-        conf = open(self._conf, 'w')
+        conf = open(self._conf, "w")
         yaml.dump(contents, conf, default_flow_style=False)
         conf.close()
 
@@ -387,71 +408,82 @@ class Workspace(object):
 
     @property
     def name(self):
-        return self.meta.get(self.CONF_NAME, 'none')
+        return self.meta.get(self.CONF_NAME, "none")
 
     @property
     def description(self):
-        return self.meta.get(self.CONF_DESC, 'none')
+        return self.meta.get(self.CONF_DESC, "none")
 
 
-class WorkspaceConfig(object):
-    DEFAULTS = {'string': '', 'number': 0, 'boolean': False, 'array': []}
+class WorkspaceConfiguration(object):
+    """Interface to the :data:`CONFIG_SCHEMA` JSON Schema that specifies the fields in the
+       workspace configuration.
+    """
+    DEFAULTS = {"string": "", "number": 0, "boolean": False, "array": []}
 
     def __init__(self):
         self._schema = jsonschema.Draft4Validator(CONFIG_SCHEMA)
 
-    def get_fields(self, only_defaults=False):
-        """Get all possible metadata fields for workspace config.
+    def get_fields(self, only_defaults=False) -> dict:
+        """Get the metadata fields that are in a workspace config[uration], with default values
+        provided for each field.
 
-        These values come out of the configuration schema.
-        Keys starting with a leading underscore, like '_id', are
-        skipped.
+        The default values come out of the configuration schema in :data:`CONFIG_SCHEMA`.
+        Keys starting with a leading underscore, like '_id', are skipped.
 
         Args:
-            only_defaults: Only include fields that have a default
-                                value in the schema.
-        Returns:
-            dict: Keys are field name, values are (field description, value).
-                  The 'value' gives a default value. Its type is either
-                  a list, a number, bool, or a string; the list may be empty.
-        """
-        prop = CONFIG_SCHEMA['properties']
-        result = {}
+            only_defaults: Do not return fields that are not given a default value in the schema.
 
-        for key, item in six.iteritems(prop):
-            if key.startswith('_'):
+        Returns:
+            Keys are field name, values are (field description, value). The 'value' is the default value.
+            Its type is either a list, a number, boolean, or a string.
+        """
+        result = {}  # return value
+
+        # Loop over all properties in the schema
+        for key, item in CONFIG_SCHEMA["properties"].items():
+            # Skip properties whose name starts with a leading underscore
+            if key.startswith("_"):
                 continue
-            desc = item['description']
-            type_ = item['type']
-            # morph unknown types to string
+            desc, type_ = item["description"], item["type"]
+            # Coerce unknown types to string (but print a warning, as this is not expected)
             if type_ not in self.DEFAULTS:
                 _log.warning(
                     'Unknown schema type "{}".' 'Using "string" instead'.format(type_)
                 )
-                type_ = 'string'
-            # figure out value type, look for default values
+                type_ = "string"
+            # Based on value type, extract default value
             default_value = None
-            if type_ == 'array':
-                itype = item['items']['type']
-                idesc = item['items']['description']
-                desc = '{}. Each item is a {}'.format(desc, idesc)
-                type_ = itype
-                if 'default' in item['items']:
-                    default_value = [item['items']['default']]
-                elif 'default' in item:
+            if type_ == "array":
+                # Arrays need special processing
+                item_type, item_desc = item["items"]["type"], item["items"]["description"]
+                desc = "{}. Each item is a {}".format(desc, item_desc)
+                type_ = item_type
+                # Use default either (1) inside the list of items, or (2) outside for the whole property
+                if "default" in item["items"]:
+                    default_value = [item["items"]["default"]]
+                elif "default" in item:
                     # default is comma-separated list
-                    default_value = item['default'].split(',')
+                    default_value = item["default"].split(",")
+            elif "default" in item:
+                # For everything else, simply get the "default" key
+                default_value = item["default"]
+            # Set result, except if we are in 'only_defaults' mode and there is no default value
+            if only_defaults:
+                if default_value is None:
+                    _log.debug(f"(only_defaults mode) NOT setting default value for {key}: no value provided")
                 else:
-                    default_value = []
-            elif 'default' in item:
-                default_value = item['default']
-
-            if default_value is None and only_defaults:
-                continue
-
-            if default_value is None:
-                default_value = self.DEFAULTS[type_]
-            result[key] = (desc, default_value)
+                    # Set the value
+                    result[key] = (desc, default_value)
+                    _log.debug(f"(only_defaults mode) setting default value for {key} to: {default_value}")
+            else:
+                # If not in only_defaults mode, use an internal default value based on the type when there
+                # is no default value in the schema.
+                if default_value is None:
+                    default_value = self.DEFAULTS[type_]
+                # Set the value
+                result[key] = (desc, default_value)
+                _log.debug(f"setting default value for {key} to: {default_value}")
 
         return result
 
