@@ -23,6 +23,7 @@ from pyomo.environ import (ConcreteModel,
                            Expression,
                            ExternalFunction,
                            Param,
+                           log,
                            sqrt,
                            value,
                            Var,
@@ -34,7 +35,8 @@ from idaes.core import (declare_process_block_class,
 from idaes.generic_models.properties.core.eos.ceos import Cubic, CubicType
 from idaes.generic_models.properties.core.generic.generic_property import (
         GenericParameterData)
-from idaes.core.util.exceptions import PropertyNotSupportedError
+from idaes.core.util.exceptions import ( PropertyNotSupportedError, 
+    ConfigurationError)
 from idaes.core.util.constants import Constants as const
 from idaes import bin_directory
 
@@ -71,11 +73,14 @@ class DummyParameterData(GenericParameterData):
 
 def define_state(b):
     # Add common variables
-    b.pressure = Var(initialize=101325)
-    b.temperature = Var(initialize=300)
+    b.pressure = Var(initialize=101325, units=pyunits.Pa)
+    b.temperature = Var(initialize=300, units=pyunits.K)
     b.mole_frac_phase_comp = Var(b.params.phase_list,
                                  b.params.component_list,
                                  initialize=0.5)
+    b.log_mole_frac_phase_comp = Var(b.params.phase_list,
+                                     b.params.component_list,
+                                     initialize=0)
 
     # Set mole fractions for each phase so they can be distinguished
     if "Sol" not in b.params.phase_list:
@@ -85,6 +90,11 @@ def define_state(b):
         b.mole_frac_phase_comp["Liq", "a"].value = 0.6
         b.mole_frac_phase_comp["Liq", "b"].value = 0.3
         b.mole_frac_phase_comp["Liq", "c"].value = 0.1
+        
+        for p in ["Liq","Vap"]:
+            for j in "abc":
+                b.log_mole_frac_phase_comp[p,j].value = log(
+                    b.mole_frac_phase_comp[p,j].value)
 
 
 @pytest.fixture()
@@ -149,65 +159,6 @@ def m():
     return m
 
 
-@pytest.fixture()
-def m_sol():
-    m = ConcreteModel()
-
-    # Dummy params block
-    m.params = DummyParameterBlock(default={
-                "components": {
-                    "a": {"phase_equilibrium_form": {("Sol", "Liq"): dummy_pe},
-                          "parameter_data": {
-                              "omega": 0.1,
-                              "pressure_crit": 1e5,
-                              "temperature_crit": 100}},
-                    "b": {"phase_equilibrium_form": {("Sol", "Liq"): dummy_pe},
-                          "parameter_data": {
-                              "omega": 0.2,
-                              "pressure_crit": 2e5,
-                              "temperature_crit": 200}},
-                    "c": {"phase_equilibrium_form": {("Sol", "Liq"): dummy_pe},
-                          "parameter_data": {
-                              "omega": 0.3,
-                              "pressure_crit": 3e5,
-                              "temperature_crit": 300}}},
-                "phases": {
-                    "Sol": {"type": SolidPhase,
-                            "equation_of_state": Cubic,
-                            "equation_of_state_options": {
-                                "type": CubicType.PR}},
-                    "Liq": {"type": LiquidPhase,
-                            "equation_of_state": Cubic,
-                            "equation_of_state_options": {
-                                "type": CubicType.PR}}},
-                "base_units": {"time": pyunits.s,
-                               "length": pyunits.m,
-                               "mass": pyunits.kg,
-                               "amount": pyunits.mol,
-                               "temperature": pyunits.K},
-                "state_definition": modules[__name__],
-                "pressure_ref": 1e5,
-                "temperature_ref": 300,
-                "phases_in_equilibrium": [("Sol", "Liq")],
-                "phase_equilibrium_state": {("Sol", "Liq"): modules[__name__]},
-                "parameter_data": {"PR_kappa": {("a", "a"): 0.000,
-                                                ("a", "b"): 0.000,
-                                                ("a", "c"): 0.000,
-                                                ("b", "a"): 0.000,
-                                                ("b", "b"): 0.000,
-                                                ("b", "c"): 0.000,
-                                                ("c", "a"): 0.000,
-                                                ("c", "b"): 0.000,
-                                                ("c", "c"): 0.000}}})
-
-    m.props = m.params.state_block_class(
-        [1], default={"defined_state": False,
-                      "parameters": m.params,
-                      "has_phase_equilibrium": True})
-
-    return m
-
-
 # Expected values for A and B
 Al = 0.0419062
 Bl = 0.0262770
@@ -231,6 +182,194 @@ _so = os.path.join(bin_directory, "cubic_roots.so")
 f_Zl = ExternalFunction(library=_so, function="ceos_z_liq")
 f_Zv = ExternalFunction(library=_so, function="ceos_z_vap")
 
+@pytest.mark.unit
+def test_wrong_phase():
+    m = ConcreteModel()
+    with pytest.raises(PropertyNotSupportedError):
+        m.params = DummyParameterBlock(default={
+                    "components": {
+                        "a": {"phase_equilibrium_form": {("Sol", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.1,
+                                  "pressure_crit": 1e5,
+                                  "temperature_crit": 100}}},
+                    "phases": {
+                        "Sol": {"type": SolidPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR}}
+                        },
+                    "base_units": {"time": pyunits.s,
+                                    "length": pyunits.m,
+                                    "mass": pyunits.kg,
+                                    "amount": pyunits.mol,
+                                    "temperature": pyunits.K},
+                    "state_definition": modules[__name__],
+                    "pressure_ref": 1e5,
+                    "temperature_ref": 300,
+                    "phases_in_equilibrium": [("Vap", "Liq")],
+                    "phase_equilibrium_state": {("Vap", "Liq"): modules[__name__]},
+                    "parameter_data": {"PR_kappa": {("a", "a"): 0.000}}})
+
+@pytest.mark.unit
+def test_unknown_eos_option():
+    m = ConcreteModel()
+    with pytest.raises(ConfigurationError):
+        m.params = DummyParameterBlock(default={
+                    "components": {
+                        "a": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.1,
+                                  "pressure_crit": 1e5,
+                                  "temperature_crit": 100}}},
+                    "phases": {
+                        "Vap": {"type": VaporPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": "PR"}}
+                        },
+                    "base_units": {"time": pyunits.s,
+                                    "length": pyunits.m,
+                                    "mass": pyunits.kg,
+                                    "amount": pyunits.mol,
+                                    "temperature": pyunits.K},
+                    "state_definition": modules[__name__],
+                    "pressure_ref": 1e5,
+                    "temperature_ref": 300,
+                    "phases_in_equilibrium": [("Vap", "Liq")],
+                    "phase_equilibrium_state": {("Vap", "Liq"): modules[__name__]},
+                    "parameter_data": {"PR_kappa": {("a", "a"): 0.000}}})
+
+@pytest.mark.unit
+def test_mixing_rule_fail():
+    m = ConcreteModel()
+
+    # Dummy params block
+    with pytest.raises(ValueError):
+        m.params = DummyParameterBlock(default={
+                    "components": {
+                        "a": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.1,
+                                  "pressure_crit": 1e5,
+                                  "temperature_crit": 100}},
+                        "b": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.2,
+                                  "pressure_crit": 2e5,
+                                  "temperature_crit": 200}}},
+                    "phases": {
+                        "Vap": {"type": VaporPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR,
+                                    "mixing_rule_a": "wong_sandler"}},
+                        "Liq": {"type": LiquidPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR}}},
+                    "base_units": {"time": pyunits.s,
+                                    "length": pyunits.m,
+                                    "mass": pyunits.kg,
+                                    "amount": pyunits.mol,
+                                    "temperature": pyunits.K},
+                    "state_definition": modules[__name__],
+                    "pressure_ref": 1e5,
+                    "temperature_ref": 300,
+                    "phases_in_equilibrium": [("Vap", "Liq")],
+                    "phase_equilibrium_state": {("Vap", "Liq"): modules[__name__]},
+                    "parameter_data": {"PR_kappa": {("a", "a"): 0.000,
+                                                    ("a", "b"): 0.000,
+                                                    ("b", "a"): 0.000,
+                                                    ("b", "b"): 0.000,}}})
+        
+# This test can be resuscitated when we actually implement another mixing rule
+# @pytest.mark.unit
+# def test_mixing_rule_mismatch():
+#     m = ConcreteModel()
+
+#     # Dummy params block
+#     with pytest.raises(ConfigurationError):
+#         m.params = DummyParameterBlock(default={
+#                     "components": {
+#                         "a": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+#                               "parameter_data": {
+#                                   "omega": 0.1,
+#                                   "pressure_crit": 1e5,
+#                                   "temperature_crit": 100}},
+#                         "b": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+#                               "parameter_data": {
+#                                   "omega": 0.2,
+#                                   "pressure_crit": 2e5,
+#                                   "temperature_crit": 200}}},
+#                     "phases": {
+#                         "Vap": {"type": VaporPhase,
+#                                 "equation_of_state": Cubic,
+#                                 "equation_of_state_options": {
+#                                     "type": CubicType.PR,
+#                                     "mixing_rule_a": MixingRuleA.default}},
+#                         "Liq": {"type": LiquidPhase,
+#                                 "equation_of_state": Cubic,
+#                                 "equation_of_state_options": {
+#                                     "type": CubicType.PR,
+#                                     "mixing_rule_a": MixingRuleA.dummy}}},
+#                     "base_units": {"time": pyunits.s,
+#                                     "length": pyunits.m,
+#                                     "mass": pyunits.kg,
+#                                     "amount": pyunits.mol,
+#                                     "temperature": pyunits.K},
+#                     "state_definition": modules[__name__],
+#                     "pressure_ref": 1e5,
+#                     "temperature_ref": 300,
+#                     "phases_in_equilibrium": [("Vap", "Liq")],
+#                     "phase_equilibrium_state": {("Vap", "Liq"): modules[__name__]},
+#                     "parameter_data": {"PR_kappa": {("a", "a"): 0.000,
+#                                                     ("a", "b"): 0.000,
+#                                                     ("b", "a"): 0.000,
+#                                                     ("b", "b"): 0.000,}}})
+
+@pytest.mark.unit
+def test_config_fail():
+    m = ConcreteModel()
+
+    # Dummy params block
+    with pytest.raises(ValueError):
+        m.params = DummyParameterBlock(default={
+                    "components": {
+                        "a": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.1,
+                                  "pressure_crit": 1e5,
+                                  "temperature_crit": 100}},
+                        "b": {"phase_equilibrium_form": {("Vap", "Liq"): dummy_pe},
+                              "parameter_data": {
+                                  "omega": 0.2,
+                                  "pressure_crit": 2e5,
+                                  "temperature_crit": 200}}},
+                    "phases": {
+                        "Vap": {"type": VaporPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR,
+                                    "mixing_rule_a": "wong_sandler"}},
+                        "Liq": {"type": LiquidPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR}}},
+                    "base_units": {"time": pyunits.s,
+                                    "length": pyunits.m,
+                                    "mass": pyunits.kg,
+                                    "amount": pyunits.mol,
+                                    "temperature": pyunits.K},
+                    "state_definition": modules[__name__],
+                    "pressure_ref": 1e5,
+                    "temperature_ref": 300,
+                    "phases_in_equilibrium": [("Vap", "Liq")],
+                    "phase_equilibrium_state": {("Vap", "Liq"): modules[__name__]},
+                    "parameter_data": {"PR_kappa": {("a", "a"): 0.000,
+                                                    ("a", "b"): 0.000,
+                                                    ("b", "a"): 0.000,
+                                                    ("b", "b"): 0.000,}}})
 
 @pytest.mark.unit
 def test_common(m):
@@ -314,10 +453,25 @@ def test_common(m):
                     (1-m.params.PR_kappa[i, j])
                     for j in m.params.component_list))
 
-    assert isinstance(m.props[1].PR_dadT, Expression)
-    assert len(m.props[1].PR_dadT) == len(m.params.phase_list)
+    assert isinstance(m.props[1].PR_daij_dT,Expression)
+    assert len(m.props[1].PR_daij_dT) == len(m.params.component_list)**2
+    for i in m.params.component_list:
+        for j in m.params.component_list:
+            assert pytest.approx(value(m.props[1].PR_daij_dT[i,j])
+                                 == (1-m.params.PR_kappa[i, j])
+                                 * (m.props[1].PR_fw[j] 
+                                 * sqrt(m.props[1].PR_a[i]
+                                     *  m.params.get_component(j).temperature_crit
+                                     / m.params.get_component(j).pressure_crit)
+                                  + m.props[1].PR_fw[i]
+                                  * sqrt(m.props[1].PR_a[j]
+                                      * m.params.get_component(i).temperature_crit
+                                      / m.params.get_component(i).pressure_crit)))
+                                     
+    assert isinstance(m.props[1].PR_dam_dT, Expression)
+    assert len(m.props[1].PR_dam_dT) == len(m.params.phase_list)
     for p in m.params.phase_list:
-        assert pytest.approx(value(m.props[1].PR_dadT[p]),
+        assert pytest.approx(value(m.props[1].PR_dam_dT[p]),
                              rel=1e-5) == value(
             -((const.gas_constant/2)*sqrt(0.45724) *
               sum(sum(m.props[1].mole_frac_phase_comp[p, i] *
@@ -334,7 +488,29 @@ def test_common(m):
                       for j in m.params.component_list)
                   for i in m.params.component_list) /
               sqrt(m.props[1].temperature)))
-
+                                 
+    assert isinstance(m.props[1].PR_d2am_dT2, Expression)
+    assert len(m.props[1].PR_d2am_dT2) == len(m.params.phase_list)
+    T = m.props[1].temperature
+    R = const.gas_constant
+    for p in m.params.phase_list:
+        assert (pytest.approx(value(m.props[1].PR_d2am_dT2[p]))
+            == value(-(0.5/T)*m.props[1].PR_dam_dT[p] + ((R**2*0.45724)/(2*T)) 
+            *sum(
+                sum(m.props[1].mole_frac_phase_comp[p, i]
+                    * m.props[1].mole_frac_phase_comp[p, j]
+                    * (1 - m.params.PR_kappa[i, j])
+                    * m.props[1].PR_fw[i]*m.props[1].PR_fw[j]
+                        * sqrt((m.params.get_component(i).temperature_crit
+                                * m.params.get_component(j).temperature_crit)
+                               /(m.params.get_component(i).pressure_crit
+                                 * m.params.get_component(j).pressure_crit)
+                               )
+                    for j in m.params.component_list)
+                for i in m.params.component_list)
+                )
+            )
+    
     # Test equilibrium state Expressions
     assert isinstance(m.props[1]._PR_a_eq, Expression)
     assert len(m.props[1]._PR_a_eq) == len(m.params.component_list)
@@ -427,12 +603,6 @@ def test_compress_fact_phase_Vap(m):
         Cubic.compress_fact_phase(m.props[1], "Vap")), rel=1e-5) == Zv
 
 
-@pytest.mark.unit
-def test_compress_fact_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.compress_fact_phase(m_sol.props[1], "Sol")
-
-
 @pytest.mark.unit
 def test_dens_mass_phase(m):
     m.props[1].dens_mol_phase = Var(m.params.phase_list)
@@ -451,12 +621,6 @@ def test_dens_mol_phase(m):
             41.157, rel=1e-3)
 
 
-@pytest.mark.unit
-def test_dens_mol_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.dens_mol_phase(m_sol.props[1], "Sol")
-
-
 @pytest.mark.unit
 def test_energy_internal_mol_phase(m):
     for j in m.params.component_list:
@@ -475,21 +639,19 @@ def test_energy_internal_mol_phase(m):
 
 @pytest.mark.unit
 def test_energy_internal_mol_phase_comp(m):
-    for j in m.params.component_list:
-        m.params.config.include_enthalpy_of_formation = False
-        m.params.get_component(j).config.enth_mol_liq_comp = dummy_call
-        m.params.get_component(j).config.enth_mol_ig_comp = dummy_call
+    m.props[1].enth_mol_phase_comp = Var(m.params.phase_list,
+                                         m.params.component_list)
+    m.props[1].vol_mol_phase_comp = Var(m.params.phase_list,
+                                         m.params.component_list)
 
-        assert pytest.approx(Ul, rel=1e-4) == value(
-            Cubic.energy_internal_mol_phase_comp(m.props[1], "Liq", j))
-        assert pytest.approx(Uv, rel=1e-4) == value(
-            Cubic.energy_internal_mol_phase_comp(m.props[1], "Vap", j))
-
-
-@pytest.mark.unit
-def test_energy_internal_mol_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.energy_internal_mol_phase_comp(m_sol.props[1], "Sol", "foo")
+    for p in m.params.phase_list:
+        for j in m.params.component_list:
+            assert (str(Cubic.energy_internal_mol_phase_comp(m.props[1], p, j)) 
+                    == str(m.props[1].enth_mol_phase_comp[p, j] -
+                           m.props[1].pressure
+                           * m.props[1].vol_mol_phase_comp[p, j]
+                           )
+                    )
 
 
 @pytest.mark.unit
@@ -510,21 +672,31 @@ def test_enth_mol_phase(m):
 
 @pytest.mark.unit
 def test_enth_mol_phase_comp(m):
+    enth = {("Liq", "a"): -23.8270,
+            ("Vap", "a"): 345.7288,
+            ("Liq", "b"): -407.3709,
+            ("Vap", "b"): -385.7457,
+            ("Liq", "c"): -757.0346,
+            ("Vap", "c"): -1052.4697}
     for j in m.params.component_list:
         m.params.get_component(j).config.enth_mol_liq_comp = dummy_call
         m.params.get_component(j).config.enth_mol_ig_comp = dummy_call
-
-        assert pytest.approx(Hl, rel=1e-5) == value(
+            
+        assert pytest.approx(enth["Liq",j], rel=1e-5) == value(
             Cubic.enth_mol_phase_comp(m.props[1], "Liq", j))
-        assert pytest.approx(Hv, rel=1e-5) == value(
+        assert pytest.approx(enth["Vap",j], rel=1e-5) == value(
             Cubic.enth_mol_phase_comp(m.props[1], "Vap", j))
-
-
-@pytest.mark.unit
-def test_enth_mol_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.enth_mol_phase_comp(m_sol.props[1], "Sol", "foo")
-
+        
+    assert pytest.approx(Hl, rel=1e-5) == value(
+            sum(Cubic.enth_mol_phase_comp(m.props[1], "Liq", j)
+                * m.props[1].mole_frac_phase_comp["Liq", j]
+                for j in m.params.component_list)
+            )
+    assert pytest.approx(Hv, rel=1e-5) == value(
+            sum(Cubic.enth_mol_phase_comp(m.props[1], "Vap", j)
+                * m.props[1].mole_frac_phase_comp["Vap", j]
+                for j in m.params.component_list)
+            )
 
 @pytest.mark.unit
 def test_entr_mol_phase(m):
@@ -537,19 +709,19 @@ def test_entr_mol_phase(m):
                                          initialize=1)
 
     assert pytest.approx(value(
-        Cubic.entr_mol_phase(m.props[1], "Vap")), rel=1e-5) == 39.9218
+        Cubic.entr_mol_phase(m.props[1], "Vap")), rel=1e-5) == 46.58858
     assert pytest.approx(value(
-        Cubic.entr_mol_phase(m.props[1], "Liq")), rel=1e-5) == 41.1621
+        Cubic.entr_mol_phase(m.props[1], "Liq")), rel=1e-5) == 48.62807
 
 
 @pytest.mark.unit
 def test_entr_mol_phase_comp(m):
-    entr = {("Liq", "a"): 45.4093,
-            ("Vap", "a"): 59.0666,
-            ("Liq", "b"): 51.1725,
-            ("Vap", "b"): 53.3035,
-            ("Liq", "c"): 60.3069,
-            ("Vap", "c"): 42.8875}
+    entr = {("Liq", "a"): 45.8181,
+            ("Vap", "a"): 61.5670,
+            ("Liq", "b"): 50.7494,
+            ("Vap", "b"): 54.1797,
+            ("Liq", "c"): 59.1236,
+            ("Vap", "c"): 42.2799}
     for j in m.params.component_list:
         m.params.get_component(j).config.entr_mol_liq_comp = dummy_call
         m.params.get_component(j).config.entr_mol_ig_comp = dummy_call
@@ -558,14 +730,20 @@ def test_entr_mol_phase_comp(m):
             Cubic.entr_mol_phase_comp(m.props[1], "Liq", j))
         assert pytest.approx(entr[("Vap", j)], rel=1e-5) == value(
             Cubic.entr_mol_phase_comp(m.props[1], "Vap", j))
-
-
-@pytest.mark.unit
-def test_entr_mol_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.entr_mol_phase_comp(m_sol.props[1], "Sol", "foo")
-
-
+        
+    # With real partial molar quantities implemented, we should have that
+    # the sum weighted by mole fraction is equal to the molar entropy
+    assert (pytest.approx(value(
+            Cubic.entr_mol_phase(m.props[1], "Liq")), rel=1e-5)
+            == value(sum(Cubic.entr_mol_phase_comp(m.props[1], "Liq", j)
+                         *m.props[1].mole_frac_phase_comp["Liq", j]
+                         for j in m.params.component_list))
+            )
+    assert (pytest.approx(value(
+            Cubic.entr_mol_phase(m.props[1], "Vap")), rel=1e-5)
+            == value(sum(Cubic.entr_mol_phase_comp(m.props[1], "Vap", j)
+                         *m.props[1].mole_frac_phase_comp["Vap", j]
+                         for j in m.params.component_list)))
 @pytest.mark.component
 def test_fug_phase_comp(m):
     for p in m.params.phase_list:
@@ -577,12 +755,6 @@ def test_fug_phase_comp(m):
                 m.props[1].fug_coeff_phase_comp[p, j])
 
 
-@pytest.mark.unit
-def test_fug_phase_comp_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.fug_phase_comp(m_sol.props[1], "Sol", "foo")
-
-
 @pytest.mark.component
 def test_fug_phase_comp_eq(m):
     for p in m.params.phase_list:
@@ -595,12 +767,6 @@ def test_fug_phase_comp_eq(m):
                     m.props[1], p, j, ("Vap", "Liq")))
 
 
-@pytest.mark.unit
-def test_fug_phase_comp_eq_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.fug_phase_comp_eq(m_sol.props[1], "Sol", "foo", ("Vap", "Liq"))
-
-
 @pytest.mark.unit
 def test_fug_coeff_phase_comp_Liq(m):
     assert pytest.approx(1.01213, rel=1e-5) == value(
@@ -621,12 +787,6 @@ def test_fug_coeff_phase_comp_Vap(m):
         Cubic.fug_coeff_phase_comp(m.props[1], "Vap", "c"))
 
 
-@pytest.mark.unit
-def test_fug_coeff_phase_comp_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.fug_coeff_phase_comp(m_sol.props[1], "Sol", "foo")
-
-
 @pytest.mark.unit
 def test_fug_coeff_phase_comp_eq_Liq(m):
     assert pytest.approx(1.22431, rel=1e-5) == value(
@@ -647,13 +807,6 @@ def test_fug_coeff_phase_comp_eq_Vap(m):
         Cubic.fug_coeff_phase_comp_eq(m.props[1], "Vap", "c", ("Vap", "Liq")))
 
 
-@pytest.mark.unit
-def test_fug_coeff_phase_comp_eq_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.fug_coeff_phase_comp_eq(
-            m_sol.props[1], "Sol", "foo", ("Vap", "Liq"))
-
-
 @pytest.mark.unit
 def test_gibbs_mol_phase(m):
     m.props[1].enth_mol_phase = Var(m.params.phase_list)
@@ -667,17 +820,19 @@ def test_gibbs_mol_phase(m):
 
 @pytest.mark.unit
 def test_gibbs_mol_phase_comp(m):
-    m.props[1].enth_mol_phase_comp = Var(m.params.phase_list,
-                                         m.params.component_list)
-    m.props[1].entr_mol_phase_comp = Var(m.params.phase_list,
-                                         m.params.component_list)
+    for j in m.params.component_list:
+        m.params.get_component(j).config.entr_mol_ig_comp = dummy_call
+        m.params.get_component(j).config.enth_mol_ig_comp = dummy_call
 
     for p in m.params.phase_list:
         for j in m.params.component_list:
-            assert str(Cubic.gibbs_mol_phase_comp(m.props[1], p, j)) == str(
-                    m.props[1].enth_mol_phase_comp[p, j] -
-                    m.props[1].entr_mol_phase_comp[p, j] *
-                    m.props[1].temperature)
+            assert (pytest.approx(
+                value(Cubic.gibbs_mol_phase_comp(m.props[1], p, j)), rel=1e-5) 
+                == value(
+                    Cubic.enth_mol_phase_comp(m.props[1], p, j)
+                    - Cubic.entr_mol_phase_comp(m.props[1], p, j)
+                    * m.props[1].temperature)
+                )
 
 
 @pytest.mark.unit
@@ -687,8 +842,36 @@ def test_vol_mol_phase(m):
     assert value(Cubic.vol_mol_phase(m.props[1], "Liq")) == pytest.approx(
             1/41.157, rel=1e-3)
 
-
 @pytest.mark.unit
-def test_vol_mol_phase_invalid_phase(m_sol):
-    with pytest.raises(PropertyNotSupportedError):
-        Cubic.vol_mol_phase(m_sol.props[1], "Sol")
+def test_vol_mol_phase_comp(m):
+    vol = {("Liq", "a"): 0.0249368,
+            ("Vap", "a"): 0.0262974,
+            ("Liq", "b"): 0.0236340,
+            ("Vap", "b"): 0.0237075,
+            ("Liq", "c"): 0.0224518,
+            ("Vap", "c"): 0.0213573}
+    for j in m.params.component_list:
+        assert pytest.approx(vol[("Liq", j)], rel=1e-5) == value(
+            Cubic.vol_mol_phase_comp(m.props[1], "Liq", j))
+        assert pytest.approx(vol[("Vap", j)], rel=1e-5) == value(
+            Cubic.vol_mol_phase_comp(m.props[1], "Vap", j))
+        
+    # With real partial molar quantities implemented, we should have that
+    # the sum weighted by mole fraction is equal to the molar volume
+    assert (pytest.approx(value(
+            Cubic.vol_mol_phase(m.props[1], "Liq")), rel=1e-5)
+            == value(sum(Cubic.vol_mol_phase_comp(m.props[1], "Liq", j)
+                         *m.props[1].mole_frac_phase_comp["Liq", j]
+                         for j in m.params.component_list))
+            )
+    assert (pytest.approx(value(
+            Cubic.vol_mol_phase(m.props[1], "Vap")), rel=1e-5)
+            == value(sum(Cubic.vol_mol_phase_comp(m.props[1], "Vap", j)
+                         *m.props[1].mole_frac_phase_comp["Vap", j]
+                         for j in m.params.component_list))
+            )
+
+if __name__ == "__main__":
+    # mod = m()
+    # test_gibbs_mol_phase_comp(mod)
+    pass
\ No newline at end of file
