@@ -1,15 +1,15 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Author: Andrew Lee
 """
@@ -23,15 +23,17 @@ from idaes.generic_models.properties.core.eos.ceos import \
 from idaes.generic_models.properties.core.examples.BT_PR import configuration
 from idaes.generic_models.properties.core.generic.generic_property import (
         GenericParameterBlock)
+from pyomo.util.check_units import assert_units_consistent
 
 from pyomo.environ import (ConcreteModel,
                            Objective,
-                           SolverFactory,
                            SolverStatus,
                            TerminationCondition,
                            value)
 
-from idaes.core.util.testing import get_default_solver
+from idaes.core.util import get_solver
+from idaes.generic_models.properties.tests.test_harness import \
+    PropertyTestHarness
 
 import idaes.logger as idaeslog
 SOUT = idaeslog.INFO
@@ -43,15 +45,22 @@ prop_available = cubic_roots_available()
 
 # -----------------------------------------------------------------------------
 # Get default solver for testing
-solver = get_default_solver()
+solver = get_solver()
+# Limit iterations to make sure sweeps aren;t getting out of hand
+solver.options["max_iter"] = 50
+
+
+@pytest.mark.unit
+class TestBTPR(PropertyTestHarness):
+    def configure(self):
+        self.prop_pack = GenericParameterBlock
+        self.param_args = configuration
+        self.prop_args = {}
+        self.has_density_terms = False
 
 
 # -----------------------------------------------------------------------------
 # Test robustness and some outputs
-@pytest.mark.solver
-@pytest.mark.skipif(solver is None, reason="Solver not available")
-@pytest.mark.skipif(not prop_available,
-                    reason="Cubic root finder not available")
 class TestBTExample(object):
     @pytest.fixture()
     def m(self):
@@ -65,11 +74,16 @@ class TestBTExample(object):
                 [1],
                 default={"defined_state": True})
 
+        m.fs.state[1].calculate_scaling_factors()
+
         return m
 
     @pytest.mark.integration
     def test_T_sweep(self, m):
+        assert_units_consistent(m)
+
         m.fs.obj = Objective(expr=(m.fs.state[1].temperature - 510)**2)
+        m.fs.state[1].temperature.setub(600)
 
         for logP in range(8, 13, 1):
             m.fs.obj.deactivate()
@@ -80,13 +94,12 @@ class TestBTExample(object):
             m.fs.state[1].temperature.fix(300)
             m.fs.state[1].pressure.fix(10**(0.5*logP))
 
-            m.fs.state.initialize(outlvl=0)
+            m.fs.state.initialize()
 
             m.fs.state[1].temperature.unfix()
             m.fs.obj.activate()
 
-            solver = SolverFactory('ipopt')
-            results = solver.solve(m, tee=True)
+            results = solver.solve(m)
 
             assert results.solver.termination_condition == \
                 TerminationCondition.optimal
@@ -101,9 +114,8 @@ class TestBTExample(object):
             m.fs.state[1].temperature.fix(T)
             m.fs.state[1].pressure.fix(1e5)
 
-            m.fs.state.initialize(outlvl=0)
+            m.fs.state.initialize()
 
-            solver = SolverFactory('ipopt')
             results = solver.solve(m)
 
             assert results.solver.termination_condition == \
@@ -112,7 +124,6 @@ class TestBTExample(object):
             while m.fs.state[1].pressure.value <= 1e6:
                 m.fs.state[1].pressure.value = (
                     m.fs.state[1].pressure.value + 1e5)
-                solver = SolverFactory('ipopt')
                 results = solver.solve(m)
                 assert results.solver.termination_condition == \
                     TerminationCondition.optimal
@@ -132,7 +143,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -177,9 +187,9 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 78048.7
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -367.558
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -361.794
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -269.0553
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -264.0181
 
     @pytest.mark.component
     def test_T350_P5_x5(self, m):
@@ -195,7 +205,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -240,9 +249,9 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 75150.7
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -367.6064
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -361.8433
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -287.3318
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -281.9703
 
     @pytest.mark.component
     def test_T450_P1_x5(self, m):
@@ -258,7 +267,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -303,9 +311,9 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 84175.1
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -333.836
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -328.766
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -247.385
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -241.622
 
     @pytest.mark.component
     def test_T450_P5_x5(self, m):
@@ -321,7 +329,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -366,9 +373,9 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 83362.3
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -331.676
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -326.299
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -261.961
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -256.198
 
     @pytest.mark.component
     def test_T368_P1_x5(self, m):
@@ -384,7 +391,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -417,6 +423,7 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].mole_frac_phase_comp["Liq", "toluene"]),
                 1e-5) == 0.5987872
+        
         assert pytest.approx(
                 value(m.fs.state[1].mole_frac_phase_comp["Vap", "benzene"]),
                 1e-5) == 0.6141738
@@ -432,9 +439,9 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 77155.4
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -364.856
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -359.256
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -267.892
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -262.348
 
     @pytest.mark.component
     def test_T376_P1_x2(self, m):
@@ -450,7 +457,6 @@ class TestBTExample(object):
 
         m.fs.state.initialize(outlvl=SOUT)
 
-        solver = SolverFactory('ipopt')
         results = solver.solve(m)
 
         # Check for optimal solution
@@ -495,6 +501,54 @@ class TestBTExample(object):
         assert pytest.approx(
                 value(m.fs.state[1].enth_mol_phase["Vap"]), 1e-5) == 69175.3
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -372.869
+                value(m.fs.state[1].entr_mol_phase["Liq"]), 1e-5) == -369.033
         assert pytest.approx(
-                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -278.766
+                value(m.fs.state[1].entr_mol_phase["Vap"]), 1e-5) == -273.513
+
+    @pytest.mark.unit
+    def test_basic_scaling(self, m):
+
+        assert len(m.fs.state[1].scaling_factor) == 23
+        assert m.fs.state[1].scaling_factor[m.fs.state[1].flow_mol] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase["Liq"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase["Vap"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase_comp["Liq", "benzene"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase_comp["Liq", "toluene"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase_comp["Vap", "benzene"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].flow_mol_phase_comp["Vap", "toluene"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_comp["benzene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_comp["toluene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_phase_comp["Liq", "benzene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_phase_comp["Liq", "toluene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_phase_comp["Vap", "benzene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].mole_frac_phase_comp["Vap", "toluene"]] == 1000
+        assert m.fs.state[1].scaling_factor[m.fs.state[1].pressure] == 1e-5
+        assert m.fs.state[1].scaling_factor[m.fs.state[1].temperature] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1]._teq["Vap", "Liq"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[m.fs.state[1]._t1_Vap_Liq] == 1e-2
+
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1]._mole_frac_tbub["Vap", "Liq", "benzene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1]._mole_frac_tbub["Vap", "Liq", "toluene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1]._mole_frac_tdew["Vap", "Liq", "benzene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1]._mole_frac_tdew["Vap", "Liq", "toluene"]] == 1000
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].temperature_bubble["Vap", "Liq"]] == 1e-2
+        assert m.fs.state[1].scaling_factor[
+            m.fs.state[1].temperature_dew["Vap", "Liq"]] == 1e-2
\ No newline at end of file
