@@ -83,7 +83,7 @@ def define_state(b):
                      doc=' Total molar flowrate',
                      units=units["flow_mole"])
     b.mole_frac_comp = Var(b.component_list,
-                           bounds=(0, None),
+                           bounds=(1e-20, 1.001),
                            initialize=1 / len(b.component_list),
                            doc='Mixture mole fractions',
                            units=None)
@@ -114,7 +114,7 @@ def define_state(b):
     b.mole_frac_phase_comp = Var(
         b.phase_component_set,
         initialize=1/len(b.component_list),
-        bounds=(0, None),
+        bounds=(1e-20, 1.001),
         doc='Phase mole fractions',
         units=None)
 
@@ -190,9 +190,9 @@ def define_state(b):
             return sum(b.mole_frac_phase_comp[b.phase_list.first(), i]
                        for i in b.component_list
                        if (b.phase_list.first(), i) in b.phase_component_set) -\
-                sum(b.mole_frac_phase_comp[b.phase_list[2], i]
+                sum(b.mole_frac_phase_comp[b.phase_list.last(), i]
                     for i in b.component_list
-                    if (b.phase_list[2], i) in b.phase_component_set) == 0
+                    if (b.phase_list.last(), i) in b.phase_component_set) == 0
         b.sum_mole_frac = Constraint(rule=rule_mole_frac)
 
         def rule_phase_frac(b, p):
