@@ -40,7 +40,7 @@ from idaes.generic_models.properties.core.reactions.equilibrium_constant import
     van_t_hoff
 from idaes.generic_models.properties.core.reactions.equilibrium_forms import \
     power_law_equil
-from idaes.generic_models.properties.core.generic.generic_reaction import (
+from idaes.generic_models.properties.core.generic.utility import (
     ConcentrationForm)
 
 from idaes.core import FlowsheetBlock
