@@ -1,23 +1,20 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 
 import pytest
-from pyomo.environ import ConcreteModel, value, Var
-from pyomo.core.kernel.component_set import ComponentSet
-from pyomo.common.fileutils import this_file_dir
+from pyomo.environ import ConcreteModel, value, Var, units as pyunits
+from pyomo.common.collections import ComponentSet
 from idaes.generic_models.properties import iapws95
-import csv
-import os
 
 from idaes.core import MaterialBalanceType, EnergyBalanceType
 from idaes.core.util.exceptions import ConfigurationError
@@ -32,25 +29,25 @@ prop_available = iapws95.iapws95_available()
 @pytest.mark.unit
 def test_htpx_invalid_args():
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(300, P=101325, x=0.5)
+        iapws95.htpx(300*pyunits.K, P=101325*pyunits.Pa, x=0.5)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(100, x=0.5)
+        iapws95.htpx(100*pyunits.K, x=0.5)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(5e3, x=0.5)
+        iapws95.htpx(5e3*pyunits.K, x=0.5)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(300, P=0)
+        iapws95.htpx(300*pyunits.K, P=1e-10*pyunits.Pa)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(300, P=1e10)
+        iapws95.htpx(300*pyunits.K, P=1e10*pyunits.Pa)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(300, x=-1)
+        iapws95.htpx(300*pyunits.K, x=-1)
 
     with pytest.raises(ConfigurationError):
-        iapws95.htpx(300, x=2)
+        iapws95.htpx(300*pyunits.K, x=2)
 
 
 @pytest.mark.skipif(not prop_available, reason="IAPWS not available")
@@ -68,19 +65,24 @@ def test_htpx():
     offset = 9.22
 
     # Subcooled liquid
-    assert iapws95.htpx(300, P=101325) == pytest.approx(112143 * mw + offset, 1e-5)
+    assert iapws95.htpx(300*pyunits.K, P=101325*pyunits.Pa) == pytest.approx(
+        112143 * mw + offset, 1e-5)
 
     # Saturated liquid
-    assert iapws95.htpx(500, x=0) == pytest.approx(974919 * mw + offset, 1e-5)
+    assert iapws95.htpx(500*pyunits.K, x=0) == pytest.approx(
+        974919 * mw + offset, 1e-5)
 
     # Wet steam
-    assert iapws95.htpx(550, x=0.5) == pytest.approx(2.00138e06 * mw + offset, 1e-5)
+    assert iapws95.htpx(550*pyunits.K, x=0.5) == pytest.approx(
+        2.00138e06 * mw + offset, 1e-5)
 
     # Saturated vapor
-    assert iapws95.htpx(600, x=1) == pytest.approx(2.67730e06 * mw + offset, 1e-5)
+    assert iapws95.htpx(600*pyunits.K, x=1) == pytest.approx(
+        2.67730e06 * mw + offset, 1e-5)
 
     # Superheated steam
-    assert iapws95.htpx(400, P=101325) == pytest.approx(2.72979e06 * mw + offset, 1e-5)
+    assert iapws95.htpx(400*pyunits.K, P=101325*pyunits.Pa) == pytest.approx(
+        2.72979e06 * mw + offset, 1e-5)
 
 
 @pytest.mark.unit
@@ -111,10 +113,31 @@ class TestMixPh(object):
     @pytest.fixture(scope="class")
     def model(self):
         model = ConcreteModel()
-        model.params = iapws95.Iapws95ParameterBlock()
-
+        model.params = iapws95.Iapws95ParameterBlock(default={
+                "temperature_bounds": (249*pyunits.K, 2501*pyunits.K),
+                "pressure_bounds": (0.11*pyunits.Pa, 1.1e9*pyunits.Pa),
+                "enthalpy_mol_bounds": (
+                    0.1*pyunits.J/pyunits.mol, 1.1e5*pyunits.J/pyunits.mol),
+            }
+        )
         return model
 
+    @pytest.mark.unit
+    def test_config_enth_mass(self, model):
+        model = ConcreteModel()
+        l = 0.1/0.018
+        u = 1.1e5/0.018
+        model.params = iapws95.Iapws95ParameterBlock(default={
+                "enthalpy_mass_bounds": (
+                    l*pyunits.J/pyunits.kg,
+                    u*pyunits.J/pyunits.kg)
+            }
+        )
+        assert pytest.approx(0.1, rel=1e-3) == value(
+            model.params.default_enthalpy_bounds[0])
+        assert pytest.approx(1.1e5, rel=1e-3) == value(
+            model.params.default_enthalpy_bounds[1])
+
     @pytest.mark.unit
     def test_config(self, model):
         assert model.params.config.phase_presentation == iapws95.PhaseType.MIX
@@ -124,6 +147,19 @@ class TestMixPh(object):
         for i in model.params.phase_list:
             assert i in ["Mix"]
 
+        assert pytest.approx(249) == value(
+            model.params.default_temperature_bounds[0])
+        assert pytest.approx(2501) == value(
+            model.params.default_temperature_bounds[1])
+        assert pytest.approx(0.11) == value(
+            model.params.default_pressure_bounds[0])
+        assert pytest.approx(1.1e9) == value(
+            model.params.default_pressure_bounds[1])
+        assert pytest.approx(0.1) == value(
+            model.params.default_enthalpy_bounds[0])
+        assert pytest.approx(1.1e5) == value(
+            model.params.default_enthalpy_bounds[1])
+
     @pytest.mark.unit
     def test_build(self, model):
         model.prop = iapws95.Iapws95StateBlock(
@@ -141,7 +177,8 @@ class TestMixPh(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert value(model.prop[1].get_material_flow_terms(p, j)) == value(
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
                     model.prop[1].flow_mol
                 )
 
@@ -149,8 +186,8 @@ class TestMixPh(object):
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
             assert (
-                model.prop[1].get_enthalpy_flow_terms(p)
-                == model.prop[1].enth_mol * model.prop[1].flow_mol
+                value(model.prop[1].get_enthalpy_flow_terms(p))
+                == value(model.prop[1].enth_mol * model.prop[1].flow_mol)
             )
 
     @pytest.mark.unit
@@ -165,9 +202,9 @@ class TestMixPh(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert (
-                model.prop[1].get_energy_density_terms(p)
-                == model.prop[1].dens_mol * model.prop[1].energy_internal_mol
+            assert value(
+                model.prop[1].get_energy_density_terms(p)) == value(
+                model.prop[1].dens_mol * model.prop[1].energy_internal_mol
             )
 
     @pytest.mark.unit
@@ -220,7 +257,7 @@ class TestMixPh(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [model.prop[1].enth_mol, model.prop[1].pressure]
+            assert i.name in ["prop[1].enth_mol", "prop[1].pressure"]
 
     @pytest.mark.unit
     def test_model_check(self, model):
@@ -283,7 +320,8 @@ class TestMixPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -309,7 +347,8 @@ class TestMixPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"enth_mol": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"enth_mol": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -335,7 +374,8 @@ class TestMixPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -422,15 +462,15 @@ class TestLGPh(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -448,7 +488,7 @@ class TestLGPh(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -503,7 +543,7 @@ class TestLGPh(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [model.prop[1].enth_mol, model.prop[1].pressure]
+            assert i.name in ["prop[1].enth_mol", "prop[1].pressure"]
 
     @pytest.mark.unit
     def test_model_check(self, model):
@@ -566,7 +606,8 @@ class TestLGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -592,7 +633,8 @@ class TestLGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"enth_mol": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"enth_mol": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -618,7 +660,8 @@ class TestLGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -705,15 +748,15 @@ class TestLPh(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -731,7 +774,7 @@ class TestLPh(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -786,7 +829,7 @@ class TestLPh(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [model.prop[1].enth_mol, model.prop[1].pressure]
+            assert i.name in ["prop[1].enth_mol", "prop[1].pressure"]
 
     @pytest.mark.unit
     def test_model_check(self, model):
@@ -849,7 +892,8 @@ class TestLPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -875,7 +919,8 @@ class TestLPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"enth_mol": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"enth_mol": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -901,7 +946,8 @@ class TestLPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -988,15 +1034,15 @@ class TestGPh(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -1014,7 +1060,7 @@ class TestGPh(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -1069,7 +1115,7 @@ class TestGPh(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [model.prop[1].enth_mol, model.prop[1].pressure]
+            assert i.name in ["prop[1].enth_mol", "prop[1].pressure"]
 
     @pytest.mark.unit
     def test_model_check(self, model):
@@ -1132,7 +1178,8 @@ class TestGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -1158,7 +1205,8 @@ class TestGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"enth_mol": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"enth_mol": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -1184,7 +1232,8 @@ class TestGPh(object):
         assert not model.prop[1].enth_mol.fixed
         assert not model.prop[1].pressure.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].enth_mol.fixed
@@ -1272,16 +1321,17 @@ class TestMixTpx(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert value(model.prop[1].get_material_flow_terms(p, j)) == value(
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
                     model.prop[1].flow_mol
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert (
-                model.prop[1].get_enthalpy_flow_terms(p)
-                == model.prop[1].enth_mol * model.prop[1].flow_mol
+            assert value(
+                model.prop[1].get_enthalpy_flow_terms(p)) == value(
+                model.prop[1].enth_mol * model.prop[1].flow_mol
             )
 
     @pytest.mark.unit
@@ -1296,9 +1346,9 @@ class TestMixTpx(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert (
-                model.prop[1].get_energy_density_terms(p)
-                == model.prop[1].dens_mol * model.prop[1].energy_internal_mol
+            assert value(
+                model.prop[1].get_energy_density_terms(p)) == value(
+                model.prop[1].dens_mol * model.prop[1].energy_internal_mol
             )
 
     @pytest.mark.unit
@@ -1351,10 +1401,10 @@ class TestMixTpx(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [
-                model.prop[1].temperature,
-                model.prop[1].pressure,
-                model.prop[1].vapor_frac,
+            assert i.name in [
+                "prop[1].temperature",
+                "prop[1].pressure",
+                "prop[1].vapor_frac",
             ]
 
     @pytest.mark.unit
@@ -1432,7 +1482,8 @@ class TestMixTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1463,7 +1514,8 @@ class TestMixTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"temperature": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"temperature": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1494,7 +1546,8 @@ class TestMixTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1593,15 +1646,15 @@ class TestLgTpx(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -1619,7 +1672,7 @@ class TestLgTpx(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -1674,10 +1727,10 @@ class TestLgTpx(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [
-                model.prop[1].temperature,
-                model.prop[1].pressure,
-                model.prop[1].vapor_frac,
+            assert i.name in [
+                "prop[1].temperature",
+                "prop[1].pressure",
+                "prop[1].vapor_frac",
             ]
 
     @pytest.mark.unit
@@ -1748,7 +1801,8 @@ class TestLgTpx(object):
         assert not model.prop[1].pressure.fixed
         assert not model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1777,7 +1831,8 @@ class TestLgTpx(object):
         assert not model.prop[1].pressure.fixed
         assert not model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"temperature": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"temperature": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1806,7 +1861,8 @@ class TestLgTpx(object):
         assert not model.prop[1].pressure.fixed
         assert not model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -1899,15 +1955,15 @@ class TestLTpx(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -1925,7 +1981,7 @@ class TestLTpx(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -1980,10 +2036,10 @@ class TestLTpx(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [
-                model.prop[1].temperature,
-                model.prop[1].pressure,
-                model.prop[1].vapor_frac,
+            assert i.name in [
+                "prop[1].temperature",
+                "prop[1].pressure",
+                "prop[1].vapor_frac",
             ]
 
     @pytest.mark.unit
@@ -2054,7 +2110,8 @@ class TestLTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -2083,7 +2140,8 @@ class TestLTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"temperature": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"temperature": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -2112,7 +2170,8 @@ class TestLTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -2206,15 +2265,15 @@ class TestGTpx(object):
     def test_get_material_flow_terms(self, model):
         for p in model.params.phase_list:
             for j in model.params.component_list:
-                assert (
-                    model.prop[1].get_material_flow_terms(p, j)
-                    == model.prop[1].flow_mol * model.prop[1].phase_frac[p]
+                assert value(
+                    model.prop[1].get_material_flow_terms(p, j)) == value(
+                    model.prop[1].flow_mol * model.prop[1].phase_frac[p]
                 )
 
     @pytest.mark.unit
     def test_get_enthalpy_flow_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_enthalpy_flow_terms(p) == (
+            assert value(model.prop[1].get_enthalpy_flow_terms(p)) == value(
                 model.prop[1].enth_mol_phase[p]
                 * model.prop[1].phase_frac[p]
                 * model.prop[1].flow_mol
@@ -2232,7 +2291,7 @@ class TestGTpx(object):
     @pytest.mark.unit
     def test_get_energy_density_terms(self, model):
         for p in model.params.phase_list:
-            assert model.prop[1].get_energy_density_terms(p) == (
+            assert value(model.prop[1].get_energy_density_terms(p)) == value(
                 model.prop[1].dens_mol_phase[p]
                 * model.prop[1].energy_internal_mol_phase[p]
             )
@@ -2287,10 +2346,10 @@ class TestGTpx(object):
     @pytest.mark.unit
     def test_intensive_state_vars(self, model):
         for i in model.prop[1].intensive_set:
-            assert i in [
-                model.prop[1].temperature,
-                model.prop[1].pressure,
-                model.prop[1].vapor_frac,
+            assert i.name in [
+                "prop[1].temperature",
+                "prop[1].pressure",
+                "prop[1].vapor_frac",
             ]
 
     @pytest.mark.unit
@@ -2361,7 +2420,8 @@ class TestGTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"flow_mol": 30})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"flow_mol": 30})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -2390,7 +2450,8 @@ class TestGTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"temperature": 300})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"temperature": 300})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
@@ -2419,7 +2480,8 @@ class TestGTpx(object):
         assert not model.prop[1].pressure.fixed
         assert model.prop[1].vapor_frac.fixed
 
-        flags = model.prop.initialize(hold_state=True, state_args={"pressure": 3000})
+        flags = model.prop.initialize(hold_state=True,
+                                      state_args={"pressure": 3000})
 
         assert model.prop[1].flow_mol.fixed
         assert model.prop[1].temperature.fixed
