@@ -15,7 +15,7 @@ Standard IDAES PFR model.
 """
 # Import Pyomo libraries
 from pyomo.environ import Constraint, Var, Reference, Block
-from pyomo.common.config import ConfigBlock, ConfigValue, In
+from pyomo.common.config import ConfigBlock, ConfigValue, In, ListOf, Bool
 
 # Import IDAES cores
 from idaes.core import (ControlVolume1DBlock,
@@ -26,8 +26,7 @@ from idaes.core import (ControlVolume1DBlock,
                         UnitModelBlockData,
                         useDefault)
 from idaes.core.util.config import (is_physical_parameter_block,
-                                    is_reaction_parameter_block,
-                                    list_of_floats)
+                                    is_reaction_parameter_block)
 from idaes.core.util.misc import add_object_reference
 import idaes.core.util.unit_costing as costing
 from idaes.core.util.constants import Constants as const
@@ -83,7 +82,7 @@ balance type
 **MomentumBalanceType.momentumPhase** - momentum balances for each phase.}"""))
     CONFIG.declare("has_equilibrium_reactions", ConfigValue(
         default=False,
-        domain=In([True, False]),
+        domain=Bool,
         description="Equilibrium reaction construction flag",
         doc="""Indicates whether terms for equilibrium controlled reactions
 should be constructed,
@@ -93,7 +92,7 @@ should be constructed,
 **False** - exclude equilibrium reaction terms.}"""))
     CONFIG.declare("has_phase_equilibrium", ConfigValue(
             default=False,
-            domain=In([True, False]),
+            domain=Bool,
             description="Phase equilibrium construction flag",
             doc="""Indicates whether terms for phase equilibrium should be
 constructed,
@@ -103,7 +102,7 @@ constructed,
 **False** - exclude phase equilibrium terms.}"""))
     CONFIG.declare("has_heat_of_reaction", ConfigValue(
         default=False,
-        domain=In([True, False]),
+        domain=Bool,
         description="Heat of reaction term construction flag",
         doc="""Indicates whether terms for heat of reaction terms should be
 constructed,
@@ -113,7 +112,7 @@ constructed,
 **False** - exclude heat of reaction terms.}"""))
     CONFIG.declare("has_heat_transfer", ConfigValue(
         default=False,
-        domain=In([True, False]),
+        domain=Bool,
         description="Heat transfer term construction flag",
         doc="""Indicates whether terms for heat transfer should be constructed,
 **default** - False.
@@ -122,7 +121,7 @@ constructed,
 **False** - exclude heat transfer terms.}"""))
     CONFIG.declare("has_pressure_change", ConfigValue(
         default=False,
-        domain=In([True, False]),
+        domain=Bool,
         description="Pressure change term construction flag",
         doc="""Indicates whether terms for pressure change should be
 constructed,
@@ -166,7 +165,7 @@ and used when constructing these,
 see reaction package for documentation.}"""))
     CONFIG.declare("length_domain_set", ConfigValue(
         default=[0.0, 1.0],
-        domain=list_of_floats,
+        domain=ListOf(float),
         description="List of points to use to initialize length domain",
         doc="""A list of values to be used when constructing the length domain
 of the reactor. Point must lie between 0.0 and 1.0,
