@@ -1,15 +1,15 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Tests for Heat Exchanger 1D unit model.
 
@@ -17,8 +17,10 @@ Author: Jaffer Ghouse
 """
 import pytest
 from pyomo.environ import (ConcreteModel, TerminationCondition,
-                           SolverStatus, value)
+                           SolverStatus, value, units as pyunits)
 from pyomo.common.config import ConfigBlock
+from pyomo.util.check_units import (assert_units_consistent,
+                                    assert_units_equivalent)
 
 from idaes.core import (FlowsheetBlock, MaterialBalanceType, EnergyBalanceType,
                         MomentumBalanceType, useDefault)
@@ -26,6 +28,10 @@ from idaes.generic_models.unit_models.heat_exchanger_1D import HeatExchanger1D a
 from idaes.generic_models.unit_models.heat_exchanger_1D import WallConductionType
 from idaes.generic_models.unit_models.heat_exchanger import HeatExchangerFlowPattern
 
+from idaes.generic_models.properties.core.generic.generic_property import (
+        GenericParameterBlock)
+from idaes.generic_models.properties.core.examples.BT_PR import \
+    configuration
 from idaes.generic_models.properties.activity_coeff_models.BTX_activity_coeff_VLE \
     import BTXParameterBlock
 from idaes.generic_models.properties import iapws95
@@ -36,17 +42,26 @@ from idaes.core.util.exceptions import ConfigurationError
 from idaes.core.util.model_statistics import (degrees_of_freedom,
                                               number_variables,
                                               number_total_constraints,
-                                              fixed_variables_set,
-                                              activated_constraints_set,
                                               number_unused_variables)
-from idaes.core.util.testing import (get_default_solver,
-                                     PhysicalParameterTestBlock,
+from idaes.core.util.testing import (PhysicalParameterTestBlock,
                                      initialization_tester)
+from idaes.core.util import get_solver
+from idaes.core.util import scaling as iscale
 
 
+# Imports to assemble BT-PR with different units
+from idaes.core import LiquidPhase, VaporPhase, Component
+from idaes.generic_models.properties.core.state_definitions import FTPx
+from idaes.generic_models.properties.core.eos.ceos import Cubic, CubicType
+from idaes.generic_models.properties.core.phase_equil import SmoothVLE
+from idaes.generic_models.properties.core.phase_equil.bubble_dew import \
+        LogBubbleDew
+from idaes.generic_models.properties.core.phase_equil.forms import log_fugacity
+import idaes.generic_models.properties.core.pure.RPP4 as RPP
+
 # -----------------------------------------------------------------------------
 # Get default solver for testing
-solver = get_default_solver()
+solver = get_solver()
 
 
 # -----------------------------------------------------------------------------
@@ -165,10 +180,11 @@ class TestBTX_cocurrent(object):
         m.fs.unit.tube_inlet.mole_frac_comp[0, "benzene"].fix(0.5)
         m.fs.unit.tube_inlet.mole_frac_comp[0, "toluene"].fix(0.5)
 
+        iscale.calculate_scaling_factors(m)
+
         return m
 
     @pytest.mark.unit
-    @pytest.mark.build
     def test_build(self, btx):
         assert hasattr(btx.fs.unit, "shell_inlet")
         assert len(btx.fs.unit.shell_inlet.vars) == 4
@@ -202,7 +218,6 @@ class TestBTX_cocurrent(object):
         assert hasattr(btx.fs.unit, "shell_length")
         assert hasattr(btx.fs.unit, "tube_area")
         assert hasattr(btx.fs.unit, "tube_length")
-        assert hasattr(btx.fs.unit, "pi")
         assert hasattr(btx.fs.unit, "d_shell")
         assert hasattr(btx.fs.unit, "d_tube_outer")
         assert hasattr(btx.fs.unit, "d_tube_inner")
@@ -216,21 +231,39 @@ class TestBTX_cocurrent(object):
         assert hasattr(btx.fs.unit, "area_calc_tube")
         assert hasattr(btx.fs.unit, "area_calc_shell")
 
-        assert number_variables(btx) == 911
-        assert number_total_constraints(btx) == 845
+        assert number_variables(btx) == 869
+        assert number_total_constraints(btx) == 803
         assert number_unused_variables(btx) == 8
 
+    @pytest.mark.integration
+    def test_units(self, btx):
+        assert_units_equivalent(btx.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            btx.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            btx.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.degK)
+        assert_units_equivalent(btx.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(btx)
+
     @pytest.mark.unit
     def test_dof(self, btx):
         assert degrees_of_freedom(btx) == 0
 
     @pytest.mark.component
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     def test_initialize(self, btx):
         initialization_tester(btx)
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solve(self, btx):
@@ -241,7 +274,6 @@ class TestBTX_cocurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, btx):
@@ -259,7 +291,6 @@ class TestBTX_cocurrent(object):
         assert (pytest.approx(101325, abs=1e-3) ==
                 value(btx.fs.unit.tube_outlet.pressure[0]))
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, btx):
@@ -322,7 +353,6 @@ class TestBTX_countercurrent(object):
         return m
 
     @pytest.mark.unit
-    @pytest.mark.build
     def test_build(self, btx):
         assert hasattr(btx.fs.unit, "shell_inlet")
         assert len(btx.fs.unit.shell_inlet.vars) == 4
@@ -356,7 +386,6 @@ class TestBTX_countercurrent(object):
         assert hasattr(btx.fs.unit, "shell_length")
         assert hasattr(btx.fs.unit, "tube_area")
         assert hasattr(btx.fs.unit, "tube_length")
-        assert hasattr(btx.fs.unit, "pi")
         assert hasattr(btx.fs.unit, "d_shell")
         assert hasattr(btx.fs.unit, "d_tube_outer")
         assert hasattr(btx.fs.unit, "d_tube_inner")
@@ -370,15 +399,34 @@ class TestBTX_countercurrent(object):
         assert hasattr(btx.fs.unit, "area_calc_tube")
         assert hasattr(btx.fs.unit, "area_calc_shell")
 
-        assert number_variables(btx) == 911
-        assert number_total_constraints(btx) == 845
+        assert number_variables(btx) == 869
+        assert number_total_constraints(btx) == 803
         assert number_unused_variables(btx) == 8
 
+    @pytest.mark.integration
+    def test_units(self, btx):
+        assert_units_equivalent(btx.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            btx.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            btx.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(btx.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(btx)
+
     @pytest.mark.unit
     def test_dof(self, btx):
         assert degrees_of_freedom(btx) == 0
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_initialize(self, btx):
@@ -392,7 +440,6 @@ class TestBTX_countercurrent(object):
                                  "temperature": 331.5,
                                  "pressure": 101325})
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solve(self, btx):
@@ -403,7 +450,6 @@ class TestBTX_countercurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, btx):
@@ -421,7 +467,6 @@ class TestBTX_countercurrent(object):
         assert (pytest.approx(101325, abs=1e-3) ==
                 value(btx.fs.unit.tube_outlet.pressure[0]))
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, btx):
@@ -484,7 +529,6 @@ class TestIAPWS_cocurrent(object):
         return m
 
     @pytest.mark.unit
-    @pytest.mark.build
     def test_build(self, iapws):
         assert len(iapws.fs.unit.shell_inlet.vars) == 3
         assert hasattr(iapws.fs.unit.shell_inlet, "flow_mol")
@@ -512,7 +556,6 @@ class TestIAPWS_cocurrent(object):
         assert hasattr(iapws.fs.unit, "shell_length")
         assert hasattr(iapws.fs.unit, "tube_area")
         assert hasattr(iapws.fs.unit, "tube_length")
-        assert hasattr(iapws.fs.unit, "pi")
         assert hasattr(iapws.fs.unit, "d_shell")
         assert hasattr(iapws.fs.unit, "d_tube_outer")
         assert hasattr(iapws.fs.unit, "d_tube_inner")
@@ -526,22 +569,39 @@ class TestIAPWS_cocurrent(object):
         assert hasattr(iapws.fs.unit, "area_calc_tube")
         assert hasattr(iapws.fs.unit, "area_calc_shell")
 
-        assert number_variables(iapws) == 659
-        assert number_total_constraints(iapws) == 595
+        assert number_variables(iapws) == 617
+        assert number_total_constraints(iapws) == 553
         assert number_unused_variables(iapws) == 10
 
+    @pytest.mark.integration
+    def test_units(self, iapws):
+        assert_units_equivalent(iapws.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(iapws.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(iapws.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            iapws.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            iapws.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(iapws.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(iapws)
+
     @pytest.mark.unit
     def test_dof(self, iapws):
         assert degrees_of_freedom(iapws) == 0
 
-    @pytest.mark.initialization
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_initialize(self, iapws):
         initialization_tester(iapws)
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.unit
     def test_solve(self, iapws):
@@ -552,7 +612,6 @@ class TestIAPWS_cocurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, iapws):
@@ -571,7 +630,6 @@ class TestIAPWS_cocurrent(object):
         assert pytest.approx(101325, abs=1e2) == \
             value(iapws.fs.unit.tube_outlet.pressure[0])
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, iapws):
@@ -634,7 +692,6 @@ class TestIAPWS_countercurrent(object):
         return m
 
     @pytest.mark.unit
-    @pytest.mark.build
     def test_build(self, iapws):
         assert len(iapws.fs.unit.shell_inlet.vars) == 3
         assert hasattr(iapws.fs.unit.shell_inlet, "flow_mol")
@@ -662,7 +719,6 @@ class TestIAPWS_countercurrent(object):
         assert hasattr(iapws.fs.unit, "shell_length")
         assert hasattr(iapws.fs.unit, "tube_area")
         assert hasattr(iapws.fs.unit, "tube_length")
-        assert hasattr(iapws.fs.unit, "pi")
         assert hasattr(iapws.fs.unit, "d_shell")
         assert hasattr(iapws.fs.unit, "d_tube_outer")
         assert hasattr(iapws.fs.unit, "d_tube_inner")
@@ -676,22 +732,39 @@ class TestIAPWS_countercurrent(object):
         assert hasattr(iapws.fs.unit, "area_calc_tube")
         assert hasattr(iapws.fs.unit, "area_calc_shell")
 
-        assert number_variables(iapws) == 659
-        assert number_total_constraints(iapws) == 595
+        assert number_variables(iapws) == 617
+        assert number_total_constraints(iapws) == 553
         assert number_unused_variables(iapws) == 10
 
+    @pytest.mark.integration
+    def test_units(self, iapws):
+        assert_units_equivalent(iapws.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(iapws.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(iapws.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(iapws.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            iapws.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            iapws.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(iapws.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(iapws)
+
     @pytest.mark.unit
     def test_dof(self, iapws):
         assert degrees_of_freedom(iapws) == 0
 
-    @pytest.mark.initialization
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_initialize(self, iapws):
         initialization_tester(iapws)
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solve(self, iapws):
@@ -702,7 +775,6 @@ class TestIAPWS_countercurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, iapws):
@@ -721,7 +793,6 @@ class TestIAPWS_countercurrent(object):
         assert pytest.approx(101325, abs=1e2) == \
             value(iapws.fs.unit.tube_outlet.pressure[0])
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, iapws):
@@ -789,7 +860,6 @@ class TestSaponification_cocurrent(object):
 
         return m
 
-    @pytest.mark.build
     @pytest.mark.unit
     def test_build(self, sapon):
         assert len(sapon.fs.unit.shell_inlet.vars) == 4
@@ -820,7 +890,6 @@ class TestSaponification_cocurrent(object):
         assert hasattr(sapon.fs.unit, "shell_length")
         assert hasattr(sapon.fs.unit, "tube_area")
         assert hasattr(sapon.fs.unit, "tube_length")
-        assert hasattr(sapon.fs.unit, "pi")
         assert hasattr(sapon.fs.unit, "d_shell")
         assert hasattr(sapon.fs.unit, "d_tube_outer")
         assert hasattr(sapon.fs.unit, "d_tube_inner")
@@ -834,22 +903,39 @@ class TestSaponification_cocurrent(object):
         assert hasattr(sapon.fs.unit, "area_calc_tube")
         assert hasattr(sapon.fs.unit, "area_calc_shell")
 
-        assert number_variables(sapon) == 1037
-        assert number_total_constraints(sapon) == 959
+        assert number_variables(sapon) == 995
+        assert number_total_constraints(sapon) == 917
         assert number_unused_variables(sapon) == 14
 
+    @pytest.mark.integration
+    def test_units(self, sapon):
+        assert_units_equivalent(sapon.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(sapon.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(sapon.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            sapon.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            sapon.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(sapon.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(sapon)
+
     @pytest.mark.unit
     def test_dof(self, sapon):
         assert degrees_of_freedom(sapon) == 0
 
-    @pytest.mark.initialization
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_initialize(self, sapon):
         initialization_tester(sapon)
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solve(self, sapon):
@@ -860,7 +946,6 @@ class TestSaponification_cocurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, sapon):
@@ -901,7 +986,6 @@ class TestSaponification_cocurrent(object):
         assert pytest.approx(101325, abs=1e2) == \
             value(sapon.fs.unit.tube_outlet.pressure[0])
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, sapon):
@@ -966,7 +1050,6 @@ class TestSaponification_countercurrent(object):
 
         return m
 
-    @pytest.mark.build
     @pytest.mark.unit
     def test_build(self, sapon):
         assert len(sapon.fs.unit.shell_inlet.vars) == 4
@@ -997,7 +1080,6 @@ class TestSaponification_countercurrent(object):
         assert hasattr(sapon.fs.unit, "shell_length")
         assert hasattr(sapon.fs.unit, "tube_area")
         assert hasattr(sapon.fs.unit, "tube_length")
-        assert hasattr(sapon.fs.unit, "pi")
         assert hasattr(sapon.fs.unit, "d_shell")
         assert hasattr(sapon.fs.unit, "d_tube_outer")
         assert hasattr(sapon.fs.unit, "d_tube_inner")
@@ -1011,21 +1093,39 @@ class TestSaponification_countercurrent(object):
         assert hasattr(sapon.fs.unit, "area_calc_tube")
         assert hasattr(sapon.fs.unit, "area_calc_shell")
 
-        assert number_variables(sapon) == 1037
-        assert number_total_constraints(sapon) == 959
+        assert number_variables(sapon) == 995
+        assert number_total_constraints(sapon) == 917
         assert number_unused_variables(sapon) == 14
 
+    @pytest.mark.integration
+    def test_units(self, sapon):
+        assert_units_equivalent(sapon.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(sapon.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(sapon.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(sapon.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            sapon.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            sapon.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(sapon.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(sapon)
+
     @pytest.mark.unit
     def test_dof(self, sapon):
         assert degrees_of_freedom(sapon) == 0
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_initialize(self, sapon):
         initialization_tester(sapon)
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solve(self, sapon):
@@ -1036,7 +1136,6 @@ class TestSaponification_countercurrent(object):
             TerminationCondition.optimal
         assert results.solver.status == SolverStatus.ok
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_solution(self, sapon):
@@ -1077,7 +1176,6 @@ class TestSaponification_countercurrent(object):
         assert pytest.approx(101325, abs=1e2) == \
             value(sapon.fs.unit.tube_outlet.pressure[0])
 
-    @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.component
     def test_conservation(self, sapon):
@@ -1097,3 +1195,257 @@ class TestSaponification_countercurrent(object):
     @pytest.mark.unit
     def test_report(self, sapon):
         sapon.fs.unit.report()
+
+
+# -----------------------------------------------------------------------------
+class TestBT_Generic_cocurrent(object):
+    @pytest.fixture(scope="class")
+    def btx(self):
+        m = ConcreteModel()
+        m.fs = FlowsheetBlock(default={"dynamic": False})
+
+        # As we lack other example prop packs with units, take the generic
+        # BT-PR package and change the base units
+        configuration2 = {
+            # Specifying components
+            "components": {
+                'benzene': {
+                    "type": Component,
+                    "enth_mol_ig_comp": RPP,
+                    "entr_mol_ig_comp": RPP,
+                    "pressure_sat_comp": RPP,
+                    "phase_equilibrium_form": {("Vap", "Liq"): log_fugacity},
+                    "parameter_data": {
+                        "mw": (78.1136E-3, pyunits.kg/pyunits.mol),  # [1]
+                        "pressure_crit": (48.9e5, pyunits.Pa),  # [1]
+                        "temperature_crit": (562.2, pyunits.K),  # [1]
+                        "omega": 0.212,  # [1]
+                        "cp_mol_ig_comp_coeff": {
+                            'A': (-3.392E1, pyunits.J/pyunits.mol/pyunits.K),  # [1]
+                            'B': (4.739E-1, pyunits.J/pyunits.mol/pyunits.K**2),
+                            'C': (-3.017E-4, pyunits.J/pyunits.mol/pyunits.K**3),
+                            'D': (7.130E-8, pyunits.J/pyunits.mol/pyunits.K**4)},
+                        "enth_mol_form_vap_comp_ref": (
+                            82.9e3, pyunits.J/pyunits.mol),  # [3]
+                        "entr_mol_form_vap_comp_ref": (
+                            -269, pyunits.J/pyunits.mol/pyunits.K),  # [3]
+                        "pressure_sat_comp_coeff": {'A': (-6.98273, None),  # [1]
+                                                    'B': (1.33213, None),
+                                                    'C': (-2.62863, None),
+                                                    'D': (-3.33399, None)}}},
+                'toluene': {
+                    "type": Component,
+                    "enth_mol_ig_comp": RPP,
+                    "entr_mol_ig_comp": RPP,
+                    "pressure_sat_comp": RPP,
+                    "phase_equilibrium_form": {("Vap", "Liq"): log_fugacity},
+                    "parameter_data": {
+                        "mw": (92.1405E-3, pyunits.kg/pyunits.mol),  # [1]
+                        "pressure_crit": (41e5, pyunits.Pa),  # [1]
+                        "temperature_crit": (591.8, pyunits.K),  # [1]
+                        "omega": 0.263,  # [1]
+                        "cp_mol_ig_comp_coeff": {
+                            'A': (-2.435E1, pyunits.J/pyunits.mol/pyunits.K),  # [1]
+                            'B': (5.125E-1, pyunits.J/pyunits.mol/pyunits.K**2),
+                            'C': (-2.765E-4, pyunits.J/pyunits.mol/pyunits.K**3),
+                            'D': (4.911E-8, pyunits.J/pyunits.mol/pyunits.K**4)},
+                        "enth_mol_form_vap_comp_ref": (
+                            50.1e3, pyunits.J/pyunits.mol),  # [3]
+                        "entr_mol_form_vap_comp_ref": (
+                            -321, pyunits.J/pyunits.mol/pyunits.K),  # [3]
+                        "pressure_sat_comp_coeff": {'A': (-7.28607, None),  # [1]
+                                                    'B': (1.38091, None),
+                                                    'C': (-2.83433, None),
+                                                    'D': (-2.79168, None)}}}},
+            # Specifying phases
+            "phases":  {'Liq': {"type": LiquidPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR}},
+                        'Vap': {"type": VaporPhase,
+                                "equation_of_state": Cubic,
+                                "equation_of_state_options": {
+                                    "type": CubicType.PR}}},
+            # Set base units of measurement
+            "base_units": {"time": pyunits.s,
+                            "length": pyunits.m,
+                            "mass": pyunits.t,
+                            "amount": pyunits.mol,
+                            "temperature": pyunits.degR},
+            # Specifying state definition
+            "state_definition": FTPx,
+            "state_bounds": {"flow_mol": (0, 100, 1000, pyunits.mol/pyunits.s),
+                              "temperature": (273.15, 300, 500, pyunits.K),
+                              "pressure": (5e4, 1e5, 1e6, pyunits.Pa)},
+            "pressure_ref": (101325, pyunits.Pa),
+            "temperature_ref": (298.15, pyunits.K),
+            # Defining phase equilibria
+            "phases_in_equilibrium": [("Vap", "Liq")],
+            "phase_equilibrium_state": {("Vap", "Liq"): SmoothVLE},
+            "bubble_dew_method": LogBubbleDew,
+            "parameter_data": {"PR_kappa": {("benzene", "benzene"): 0.000,
+                                            ("benzene", "toluene"): 0.000,
+                                            ("toluene", "benzene"): 0.000,
+                                            ("toluene", "toluene"): 0.000}}}
+
+        m.fs.properties = GenericParameterBlock(default=configuration)
+        m.fs.properties2 = GenericParameterBlock(default=configuration2)
+
+        m.fs.unit = HX1D(default={
+                "shell_side": {"property_package": m.fs.properties},
+                "tube_side": {"property_package": m.fs.properties2},
+                "flow_type": HeatExchangerFlowPattern.cocurrent})
+
+        m.fs.unit.d_shell.fix(1.04)
+        m.fs.unit.d_tube_outer.fix(0.01167)
+        m.fs.unit.d_tube_inner.fix(0.01067)
+        m.fs.unit.N_tubes.fix(10)
+        m.fs.unit.shell_length.fix(4.85)
+        m.fs.unit.tube_length.fix(4.85)
+        m.fs.unit.shell_heat_transfer_coefficient.fix(2000)
+        m.fs.unit.tube_heat_transfer_coefficient.fix(51000)
+
+        m.fs.unit.shell_inlet.flow_mol[0].fix(5)  # mol/s
+        m.fs.unit.shell_inlet.temperature[0].fix(365)  # K
+        m.fs.unit.shell_inlet.pressure[0].fix(101325)  # Pa
+        m.fs.unit.shell_inlet.mole_frac_comp[0, "benzene"].fix(0.5)
+        m.fs.unit.shell_inlet.mole_frac_comp[0, "toluene"].fix(0.5)
+
+        m.fs.unit.tube_inlet.flow_mol[0].fix(1)  # mol/s
+        m.fs.unit.tube_inlet.temperature[0].fix(540)  # degR
+        m.fs.unit.tube_inlet.pressure[0].fix(101.325)  # kPa
+        m.fs.unit.tube_inlet.mole_frac_comp[0, "benzene"].fix(0.5)
+        m.fs.unit.tube_inlet.mole_frac_comp[0, "toluene"].fix(0.5)
+
+        return m
+
+    @pytest.mark.component
+    def test_build(self, btx):
+        assert hasattr(btx.fs.unit, "shell_inlet")
+        assert len(btx.fs.unit.shell_inlet.vars) == 4
+        assert hasattr(btx.fs.unit.shell_inlet, "flow_mol")
+        assert hasattr(btx.fs.unit.shell_inlet, "mole_frac_comp")
+        assert hasattr(btx.fs.unit.shell_inlet, "temperature")
+        assert hasattr(btx.fs.unit.shell_inlet, "pressure")
+
+        assert hasattr(btx.fs.unit, "tube_inlet")
+        assert len(btx.fs.unit.tube_inlet.vars) == 4
+        assert hasattr(btx.fs.unit.tube_inlet, "flow_mol")
+        assert hasattr(btx.fs.unit.tube_inlet, "mole_frac_comp")
+        assert hasattr(btx.fs.unit.tube_inlet, "temperature")
+        assert hasattr(btx.fs.unit.tube_inlet, "pressure")
+
+        assert hasattr(btx.fs.unit, "shell_outlet")
+        assert len(btx.fs.unit.shell_outlet.vars) == 4
+        assert hasattr(btx.fs.unit.shell_outlet, "flow_mol")
+        assert hasattr(btx.fs.unit.shell_outlet, "mole_frac_comp")
+        assert hasattr(btx.fs.unit.shell_outlet, "temperature")
+        assert hasattr(btx.fs.unit.shell_outlet, "pressure")
+
+        assert hasattr(btx.fs.unit, "tube_outlet")
+        assert len(btx.fs.unit.tube_outlet.vars) == 4
+        assert hasattr(btx.fs.unit.tube_outlet, "flow_mol")
+        assert hasattr(btx.fs.unit.tube_outlet, "mole_frac_comp")
+        assert hasattr(btx.fs.unit.tube_outlet, "temperature")
+        assert hasattr(btx.fs.unit.tube_outlet, "pressure")
+
+        assert hasattr(btx.fs.unit, "shell_area")
+        assert hasattr(btx.fs.unit, "shell_length")
+        assert hasattr(btx.fs.unit, "tube_area")
+        assert hasattr(btx.fs.unit, "tube_length")
+        assert hasattr(btx.fs.unit, "d_shell")
+        assert hasattr(btx.fs.unit, "d_tube_outer")
+        assert hasattr(btx.fs.unit, "d_tube_inner")
+        assert hasattr(btx.fs.unit, "N_tubes")
+        assert hasattr(btx.fs.unit, "shell_heat_transfer_coefficient")
+        assert hasattr(btx.fs.unit, "tube_heat_transfer_coefficient")
+        assert hasattr(btx.fs.unit, "temperature_wall")
+        assert hasattr(btx.fs.unit, "shell_heat_transfer_eq")
+        assert hasattr(btx.fs.unit, "tube_heat_transfer_eq")
+        assert hasattr(btx.fs.unit, "wall_0D_model")
+        assert hasattr(btx.fs.unit, "area_calc_tube")
+        assert hasattr(btx.fs.unit, "area_calc_shell")
+
+        assert number_variables(btx) == 2021
+        assert number_total_constraints(btx) == 1889
+        assert number_unused_variables(btx) == 34
+
+    @pytest.mark.integration
+    def test_units(self, btx):
+        assert_units_equivalent(btx.fs.unit.shell_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.shell_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.tube_area, pyunits.m**2)
+        assert_units_equivalent(btx.fs.unit.tube_length, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_shell, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_outer, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.d_tube_inner, pyunits.m)
+        assert_units_equivalent(btx.fs.unit.N_tubes, pyunits.dimensionless)
+        assert_units_equivalent(
+            btx.fs.unit.shell_heat_transfer_coefficient,
+            pyunits.W/pyunits.m**2/pyunits.K)
+        assert_units_equivalent(
+            btx.fs.unit.tube_heat_transfer_coefficient,
+            pyunits.kW/pyunits.m**2/pyunits.degR)
+        assert_units_equivalent(btx.fs.unit.temperature_wall, pyunits.K)
+
+        assert_units_consistent(btx)
+
+    @pytest.mark.component
+    def test_dof(self, btx):
+        assert degrees_of_freedom(btx) == 0
+
+    @pytest.mark.skipif(solver is None, reason="Solver not available")
+    @pytest.mark.integration
+    def test_initialize(self, btx):
+        initialization_tester(btx)
+
+    @pytest.mark.skipif(solver is None, reason="Solver not available")
+    @pytest.mark.integration
+    def test_solve(self, btx):
+        results = solver.solve(btx)
+
+        # Check for optimal solution
+        assert results.solver.termination_condition == \
+            TerminationCondition.optimal
+        assert results.solver.status == SolverStatus.ok
+
+    @pytest.mark.skipif(solver is None, reason="Solver not available")
+    @pytest.mark.integration
+    def test_solution(self, btx):
+        assert (pytest.approx(5, abs=1e-3) ==
+                value(btx.fs.unit.shell_outlet.flow_mol[0]))
+        assert (pytest.approx(322.959, abs=1e-3) ==
+                value(btx.fs.unit.shell_outlet.temperature[0]))
+        assert (pytest.approx(101325, abs=1e-3) ==
+                value(btx.fs.unit.shell_outlet.pressure[0]))
+
+        assert (pytest.approx(1, abs=1e-3) ==
+                value(btx.fs.unit.tube_outlet.flow_mol[0]))
+        assert (pytest.approx(581.126, abs=1e-3) ==
+                value(btx.fs.unit.tube_outlet.temperature[0]))
+        assert (pytest.approx(101.325, abs=1e-3) ==
+                value(btx.fs.unit.tube_outlet.pressure[0]))
+
+    @pytest.mark.skipif(solver is None, reason="Solver not available")
+    @pytest.mark.integration
+    def test_conservation(self, btx):
+        assert abs(value(btx.fs.unit.shell_inlet.flow_mol[0] -
+                         btx.fs.unit.shell_outlet.flow_mol[0])) <= 1e-6
+        assert abs(value(btx.fs.unit.tube_inlet.flow_mol[0] -
+                         btx.fs.unit.tube_outlet.flow_mol[0])) <= 1e-6
+
+        shell_side = value(
+                btx.fs.unit.shell_outlet.flow_mol[0] *
+                (btx.fs.unit.shell.properties[0, 0].enth_mol_phase['Liq'] -
+                 btx.fs.unit.shell.properties[0, 1].enth_mol_phase['Liq']))
+        tube_side = value(pyunits.convert(
+                btx.fs.unit.tube_outlet.flow_mol[0]*btx.fs.unit.N_tubes *
+                (btx.fs.unit.tube.properties[0, 1].enth_mol_phase['Liq'] -
+                 btx.fs.unit.tube.properties[0, 0].enth_mol_phase['Liq']),
+                to_units=pyunits.W))
+        assert abs((shell_side - tube_side)/shell_side) <= 1e-4
+
+    @pytest.mark.ui
+    @pytest.mark.component
+    def test_report(self, btx):
+        btx.fs.unit.report()
