@@ -1,15 +1,15 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Tests for Pressure Changer unit model.
 
@@ -24,7 +24,8 @@ from pyomo.environ import (ConcreteModel,
                            units,
                            value,
                            Var)
-
+from pyomo.util.check_units import (assert_units_consistent,
+                                    assert_units_equivalent)
 from pyomo.util.calc_var_value import calculate_variable_from_constraint
 
 from idaes.core import (FlowsheetBlock,
@@ -51,15 +52,15 @@ from idaes.core.util.model_statistics import (degrees_of_freedom,
                                               number_variables,
                                               number_total_constraints,
                                               number_unused_variables)
-from idaes.core.util.testing import (get_default_solver,
-                                     PhysicalParameterTestBlock,
+from idaes.core.util.testing import (PhysicalParameterTestBlock,
                                      initialization_tester)
 from idaes.core.util.exceptions import BalanceTypeNotSupportedError
+from idaes.core.util import get_solver, scaling as iscale
 
 
 # -----------------------------------------------------------------------------
 # Get default solver for testing
-solver = get_default_solver()
+solver = get_solver()
 
 
 # -----------------------------------------------------------------------------
@@ -80,7 +81,7 @@ class TestPressureChanger(object):
                 "property_package": m.fs.properties})
 
         # Check unit config arguments
-        assert len(m.fs.unit.config) == 10
+        assert len(m.fs.unit.config) == 12
 
         assert m.fs.unit.config.material_balance_type == \
             MaterialBalanceType.useDefault
@@ -103,6 +104,7 @@ class TestPressureChanger(object):
 
         m.fs.unit = PressureChanger(default={
                 "property_package": m.fs.properties})
+        iscale.calculate_scaling_factors(m)
 
         assert hasattr(m.fs.unit, "volume")
 
@@ -116,6 +118,7 @@ class TestPressureChanger(object):
         m.fs.unit = PressureChanger(default={
                 "property_package": m.fs.properties,
                 "thermodynamic_assumption": ThermodynamicAssumption.pump})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit.fluid_work_calculation, Constraint)
 
@@ -129,8 +132,8 @@ class TestPressureChanger(object):
         m.fs.unit = PressureChanger(default={
                 "property_package": m.fs.properties,
                 "thermodynamic_assumption": ThermodynamicAssumption.adiabatic})
+        iscale.calculate_scaling_factors(m)
 
-        assert isinstance(m.fs.unit.adiabatic, Constraint)
 
     @pytest.mark.unit
     def test_isentropic_comp_phase_balances(self):
@@ -143,6 +146,7 @@ class TestPressureChanger(object):
                 "property_package": m.fs.properties,
                 "thermodynamic_assumption": ThermodynamicAssumption.isentropic,
                 "material_balance_type": MaterialBalanceType.componentPhase})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit.state_material_balances, Constraint)
         assert len(m.fs.unit.state_material_balances) == 4
@@ -158,6 +162,7 @@ class TestPressureChanger(object):
                 "property_package": m.fs.properties,
                 "thermodynamic_assumption": ThermodynamicAssumption.isentropic,
                 "material_balance_type": MaterialBalanceType.componentTotal})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit.state_material_balances, Constraint)
         assert len(m.fs.unit.state_material_balances) == 2
@@ -222,6 +227,7 @@ class TestBTX_isothermal(object):
         m.fs.unit.inlet.mole_frac_comp[0, "toluene"].fix(0.5)
 
         m.fs.unit.deltaP.fix(50000)
+        iscale.calculate_scaling_factors(m)
 
         return m
 
@@ -251,6 +257,12 @@ class TestBTX_isothermal(object):
         assert number_total_constraints(btx) == 19
         assert number_unused_variables(btx) == 0
 
+    @pytest.mark.component
+    def test_units(self, btx):
+        assert_units_consistent(btx)
+        assert_units_equivalent(btx.fs.unit.work_mechanical[0], units.W)
+        assert_units_equivalent(btx.fs.unit.deltaP[0], units.Pa)
+
     @pytest.mark.unit
     def test_dof(self, btx):
         assert degrees_of_freedom(btx) == 0
@@ -292,11 +304,11 @@ class TestBTX_isothermal(object):
         assert abs(value(btx.fs.unit.inlet.flow_mol[0] -
                          btx.fs.unit.outlet.flow_mol[0])) <= 1e-6
 
-        assert abs(btx.fs.unit.outlet.flow_mol[0] *
+        assert abs(value(btx.fs.unit.outlet.flow_mol[0] *
                    (btx.fs.unit.control_volume.properties_in[0]
                     .enth_mol_phase['Liq'] -
                     btx.fs.unit.control_volume.properties_out[0]
-                    .enth_mol_phase['Liq'])) <= 1e-6
+                    .enth_mol_phase['Liq']))) <= 1e-6
 
     @pytest.mark.ui
     @pytest.mark.unit
@@ -327,6 +339,7 @@ class TestIAPWS(object):
 
         m.fs.unit.deltaP.fix(50000)
         m.fs.unit.efficiency_isentropic.fix(0.9)
+        iscale.calculate_scaling_factors(m)
 
         return m
 
@@ -341,7 +354,7 @@ class TestIAPWS(object):
                 "property_package": m.fs.properties,
                 "thermodynamic_assumption": ThermodynamicAssumption.isentropic,
                 "compressor": False})
-
+        iscale.calculate_scaling_factors(m)
         return m
 
     @pytest.mark.build
@@ -377,6 +390,12 @@ class TestIAPWS(object):
         assert number_total_constraints(iapws) == 9
         assert number_unused_variables(iapws) == 0
 
+    @pytest.mark.component
+    def test_units(self, iapws):
+        assert_units_consistent(iapws)
+        assert_units_equivalent(iapws.fs.unit.work_mechanical[0], units.W)
+        assert_units_equivalent(iapws.fs.unit.deltaP[0], units.Pa)
+
     @pytest.mark.unit
     def test_dof(self, iapws):
         assert degrees_of_freedom(iapws) == 0
@@ -442,38 +461,36 @@ class TestIAPWS(object):
                          iapws.fs.unit.outlet.flow_mol[0])) <= 1e-6
 
         assert abs(value(
-                iapws.fs.unit.outlet.flow_mol[0] *
-                (iapws.fs.unit.inlet.enth_mol[0] -
-                 iapws.fs.unit.outlet.enth_mol[0]) +
-                iapws.fs.unit.work_mechanical[0])) <= 1e-6
+                   iapws.fs.unit.outlet.flow_mol[0] *
+                   (iapws.fs.unit.inlet.enth_mol[0] -
+                    iapws.fs.unit.outlet.enth_mol[0]) +
+                   iapws.fs.unit.work_mechanical[0])) <= 1e-6
 
     @pytest.mark.solver
     @pytest.mark.skipif(solver is None, reason="Solver not available")
     @pytest.mark.integration
     def test_verify(self, iapws_turb):
-        iapws=iapws_turb
+        iapws = iapws_turb
         # Verify the turbine results against 3 known test cases
-
         # Case Data (90% isentropic efficency)
-        # Run with Aspen Plus v10 using iapws-95
         cases = {
-            "F": (1000,1000,1000), # mol/s
-            "Tin": (500, 800, 400), # K
-            "Pin": (1000, 10000, 200), # kPa
-            "W": (-1224.64, -1911.55, -1010.64), # kW
-            "Tout": (463.435, 742.992, 382.442), # K
-            "Pout": (700, 7000, 140), # kPa
-            "xout": (1.0, 1.0, 0.9886), # vapor fraction
+            "F": (1000, 1000, 1000),  # mol/s
+            "Tin": (500, 800, 400),  # K
+            "Pin": (1000, 10000, 200),  # kPa
+            "W": (-1224.64, -1911.55, -1010.64),  # kW
+            "Tout": (463.435, 742.992, 382.442),  # K
+            "Pout": (700, 7000, 140),  # kPa
+            "xout": (1.0, 1.0, 0.9886),  # vapor fraction
             "Tisen": (460.149, 738.224, 382.442),
         }
 
-        for i in [0,1,2]:
+        for i in [0, 1, 2]:
             F = cases["F"][i]
             Tin = cases["Tin"][i]
             Tout = cases["Tout"][i]
             Pin = cases["Pin"][i]*1000
             Pout = cases["Pout"][i]*1000
-            hin = iapws95.htpx(T=Tin, P=Pin)
+            hin = iapws95.htpx(T=Tin*units.K, P=Pin*units.Pa)
             W = cases["W"][i]*1000
             Tis = cases["Tisen"][i]
             xout = cases["xout"][i]
@@ -537,6 +554,7 @@ class TestSaponification(object):
 
         m.fs.unit.deltaP.fix(-20000)
         m.fs.unit.efficiency_pump.fix(0.9)
+        iscale.calculate_scaling_factors(m)
 
         return m
 
@@ -569,6 +587,12 @@ class TestSaponification(object):
         assert number_total_constraints(sapon) == 11
         assert number_unused_variables(sapon) == 0
 
+    @pytest.mark.component
+    def test_units(self, sapon):
+        assert_units_consistent(sapon)
+        assert_units_equivalent(sapon.fs.unit.work_mechanical[0], units.W)
+        assert_units_equivalent(sapon.fs.unit.deltaP[0], units.Pa)
+
     @pytest.mark.unit
     def test_dof(self, sapon):
         assert degrees_of_freedom(sapon) == 0
@@ -646,10 +670,11 @@ class TestTurbine(object):
 
         m.fs.unit = Turbine(default={
                 "property_package": m.fs.properties})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit, PressureChangerData)
         # Check unit config arguments
-        assert len(m.fs.unit.config) == 10
+        assert len(m.fs.unit.config) == 12
 
         assert m.fs.unit.config.material_balance_type == \
             MaterialBalanceType.useDefault
@@ -663,6 +688,8 @@ class TestTurbine(object):
             ThermodynamicAssumption.isentropic
         assert m.fs.unit.config.property_package is m.fs.properties
 
+        assert_units_consistent(m.fs.unit)
+
 
 class TestCompressor(object):
     @pytest.mark.unit
@@ -674,10 +701,11 @@ class TestCompressor(object):
 
         m.fs.unit = Compressor(default={
                 "property_package": m.fs.properties})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit, PressureChangerData)
         # Check unit config arguments
-        assert len(m.fs.unit.config) == 10
+        assert len(m.fs.unit.config) == 12
 
         assert m.fs.unit.config.material_balance_type == \
             MaterialBalanceType.useDefault
@@ -691,6 +719,8 @@ class TestCompressor(object):
             ThermodynamicAssumption.isentropic
         assert m.fs.unit.config.property_package is m.fs.properties
 
+        assert_units_consistent(m.fs.unit)
+
 
 class TestPump(object):
     @pytest.mark.unit
@@ -702,10 +732,11 @@ class TestPump(object):
 
         m.fs.unit = Pump(default={
                 "property_package": m.fs.properties})
+        iscale.calculate_scaling_factors(m)
 
         assert isinstance(m.fs.unit, PressureChangerData)
         # Check unit config arguments
-        assert len(m.fs.unit.config) == 10
+        assert len(m.fs.unit.config) == 12
 
         assert m.fs.unit.config.material_balance_type == \
             MaterialBalanceType.useDefault
@@ -719,6 +750,8 @@ class TestPump(object):
             ThermodynamicAssumption.pump
         assert m.fs.unit.config.property_package is m.fs.properties
 
+        assert_units_consistent(m.fs.unit)
+
 
 @pytest.mark.skipif(not iapws95.iapws95_available(),
                     reason="IAPWS not available")
@@ -739,29 +772,24 @@ class Test_costing(object):
         m.fs.unit.inlet.pressure[0].fix(101325)
         m.fs.unit.deltaP.fix(50000)
         m.fs.unit.efficiency_pump.fix(0.9)
-        m.fs.unit.initialize()
-        m.fs.unit.work_fluid.display()
+        iscale.calculate_scaling_factors(m)
 
         assert degrees_of_freedom(m) == 0
 
         m.fs.unit.get_costing(pump_type='centrifugal',
                               Mat_factor='nickel',
                               pump_motor_type_factor='enclosed')
-        calculate_variable_from_constraint(
-                    m.fs.unit.costing.motor_purchase_cost,
-                    m.fs.unit.costing.cp_motor_cost_eq)
 
-        calculate_variable_from_constraint(
-                m.fs.unit.costing.pump_purchase_cost,
-                m.fs.unit.costing.cp_pump_cost_eq)
-
-        calculate_variable_from_constraint(
-                m.fs.unit.costing.purchase_cost,
-                m.fs.unit.costing.total_cost_eq)
-
-        results = solver.solve(m, tee=True)
+        m.fs.unit.initialize()
+        # check costing block initialization
         assert m.fs.unit.costing.purchase_cost.value == \
-            pytest.approx(70141.395, 1e-5)
+            pytest.approx(70115.019, abs=1e-2)
+
+        assert_units_consistent(m.fs.unit)
+
+        solver.solve(m, tee=True)
+        assert m.fs.unit.costing.purchase_cost.value == \
+            pytest.approx(70115.0, 1e-5)
 
     @pytest.mark.component
     def test_compressor(self):
@@ -779,16 +807,29 @@ class Test_costing(object):
         m.fs.unit.inlet.pressure[0].fix(101325)
         m.fs.unit.deltaP.fix(500000)
         m.fs.unit.efficiency_isentropic.fix(0.9)
-        m.fs.unit.initialize()
-        m.fs.unit.work_mechanical.display()
+        iscale.set_scaling_factor(m.fs.unit.control_volume.work[0], 1e-5)
+        iscale.calculate_scaling_factors(m)
+
         assert degrees_of_freedom(m) == 0
         m.fs.unit.get_costing(mover_type="compressor")
-        calculate_variable_from_constraint(
-                    m.fs.unit.costing.purchase_cost,
-                    m.fs.unit.costing.cp_cost_eq)
-        results = solver.solve(m, tee=True)
+        m.fs.unit.initialize()
+        results = solver.solve(m)
+        # Check for optimal solution
+        assert results.solver.termination_condition == \
+            TerminationCondition.optimal
+        assert results.solver.status == SolverStatus.ok
+
+        assert value(m.fs.unit.control_volume.work[0]) == \
+            pytest.approx(101410.4, rel=1e-5)
+
         assert m.fs.unit.costing.purchase_cost.value == \
-            pytest.approx(334540.7, 1e-5)
+            pytest.approx(334598, rel=1e-5)
+
+        assert_units_consistent(m.fs.unit)
+
+        solver.solve(m, tee=True)
+        assert m.fs.unit.costing.purchase_cost.value == \
+            pytest.approx(334598, rel=1e-5)
 
     @pytest.mark.component
     def test_turbine(self):
@@ -805,19 +846,108 @@ class Test_costing(object):
         Tin = 500  # K
         Pin = 1000000  # Pa
         Pout = 700000  # Pa
-        hin = iapws95.htpx(Tin, Pin)
+        hin = iapws95.htpx(Tin*units.K, Pin*units.Pa)
         m.fs.unit.inlet.enth_mol[0].fix(hin)
         m.fs.unit.inlet.pressure[0].fix(Pin)
 
         m.fs.unit.deltaP.fix(Pout - Pin)
         m.fs.unit.efficiency_isentropic.fix(0.9)
-        m.fs.unit.initialize()
-
+        # build costing block before initializing the unit
         m.fs.unit.get_costing()
-        calculate_variable_from_constraint(
-                    m.fs.unit.costing.purchase_cost,
-                    m.fs.unit.costing.cp_cost_eq)
-        assert degrees_of_freedom(m) == 0
-        results = solver.solve(m, tee=True)
+
+        m.fs.unit.initialize()
+        # check costing initialization is working
         assert m.fs.unit.costing.purchase_cost.value ==\
-            pytest.approx(213129.6059, 1e-5)
+            pytest.approx(213199, 1e-5)
+
+        assert degrees_of_freedom(m) == 0
+
+        assert_units_consistent(m.fs.unit)
+
+        solver.solve(m, tee=True)
+        assert m.fs.unit.costing.purchase_cost.value ==\
+            pytest.approx(213199, 1e-5)
+
+    @pytest.mark.component
+    def test_turbine_performance_way1(self):
+        m = ConcreteModel()
+        m.fs = FlowsheetBlock(default={"dynamic": False})
+        m.fs.properties = iapws95.Iapws95ParameterBlock()
+
+        def perf_callback(b):
+            unit_hd = units.J/units.kg
+            unit_vflw = units.m**3/units.s
+            @b.Constraint(m.fs.time)
+            def pc_isen_eff_eqn(b, t):
+                prnt = b.parent_block()
+                vflw = prnt.control_volume.properties_in[t].flow_vol
+                return prnt.efficiency_isentropic[t] == 0.9/3.975*vflw/unit_vflw
+            @b.Constraint(m.fs.time)
+            def pc_isen_head_eqn(b, t):
+                prnt = b.parent_block()
+                vflw = prnt.control_volume.properties_in[t].flow_vol
+                return b.head_isentropic[t]/1000 == \
+                    -75530.8/3.975/1000*vflw/unit_vflw*unit_hd
+
+        m.fs.unit = Turbine(default={
+            "property_package": m.fs.properties,
+            "support_isentropic_performance_curves":True,
+            "isentropic_performance_curves": {"build_callback": perf_callback}})
+
+        # set inputs
+        m.fs.unit.inlet.flow_mol[0].fix(1000)  # mol/s
+        Tin = 500  # K
+        Pin = 1000000  # Pa
+        Pout = 700000  # Pa
+        hin = iapws95.htpx(Tin*units.K, Pin*units.Pa)
+        m.fs.unit.inlet.enth_mol[0].fix(hin)
+        m.fs.unit.inlet.pressure[0].fix(Pin)
+
+        m.fs.unit.initialize()
+        assert degrees_of_freedom(m) == 0
+        assert_units_consistent(m.fs.unit)
+        solver.solve(m, tee=True)
+
+        assert value(m.fs.unit.efficiency_isentropic[0]) \
+            == pytest.approx(0.9, rel=1e-3)
+        assert value(m.fs.unit.deltaP[0]) == pytest.approx(-3e5, rel=1e-3)
+
+    @pytest.mark.component
+    def test_turbine_performance_way2(self):
+        m = ConcreteModel()
+        m.fs = FlowsheetBlock(default={"dynamic": False})
+        m.fs.properties = iapws95.Iapws95ParameterBlock()
+        m.fs.unit = Turbine(default={
+            "property_package": m.fs.properties,
+            "support_isentropic_performance_curves":True})
+        unit_hd = units.J/units.kg
+        unit_vflw = units.m**3/units.s
+        @m.fs.unit.performance_curve.Constraint(m.fs.time)
+        def pc_isen_eff_eqn(b, t):
+            prnt = b.parent_block()
+            vflw = prnt.control_volume.properties_in[t].flow_vol
+            return prnt.efficiency_isentropic[t] == 0.9/3.975*vflw/unit_vflw
+        @m.fs.unit.performance_curve.Constraint(m.fs.time)
+        def pc_isen_head_eqn(b, t):
+            prnt = b.parent_block()
+            vflw = prnt.control_volume.properties_in[t].flow_vol
+            return b.head_isentropic[t]/1000 == \
+                -75530.8/3.975/1000*vflw/unit_vflw*unit_hd
+
+        # set inputs
+        m.fs.unit.inlet.flow_mol[0].fix(1000)  # mol/s
+        Tin = 500  # K
+        Pin = 1000000  # Pa
+        Pout = 700000  # Pa
+        hin = iapws95.htpx(Tin*units.K, Pin*units.Pa)
+        m.fs.unit.inlet.enth_mol[0].fix(hin)
+        m.fs.unit.inlet.pressure[0].fix(Pin)
+
+        m.fs.unit.initialize()
+        assert degrees_of_freedom(m) == 0
+        assert_units_consistent(m.fs.unit)
+        solver.solve(m, tee=True)
+
+        assert value(m.fs.unit.efficiency_isentropic[0]) \
+            == pytest.approx(0.9, rel=1e-3)
+        assert value(m.fs.unit.deltaP[0]) == pytest.approx(-3e5, rel=1e-3)
