@@ -1,15 +1,15 @@
-##############################################################################
-# Institute for the Design of Advanced Energy Systems Process Systems
-# Engineering Framework (IDAES PSE Framework) Copyright (c) 2018-2020, by the
-# software owners: The Regents of the University of California, through
+#################################################################################
+# The Institute for the Design of Advanced Energy Systems Integrated Platform
+# Framework (IDAES IP) was produced under the DOE Institute for the
+# Design of Advanced Energy Systems (IDAES), and is copyright (c) 2018-2021
+# by the software owners: The Regents of the University of California, through
 # Lawrence Berkeley National Laboratory,  National Technology & Engineering
-# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia
-# University Research Corporation, et al. All rights reserved.
+# Solutions of Sandia, LLC, Carnegie Mellon University, West Virginia University
+# Research Corporation, et al.  All rights reserved.
 #
-# Please see the files COPYRIGHT.txt and LICENSE.txt for full copyright and
-# license information, respectively. Both files are also available online
-# at the URL "https://github.com/IDAES/idaes-pse".
-##############################################################################
+# Please see the files COPYRIGHT.md and LICENSE.md for full copyright and
+# license information.
+#################################################################################
 """
 Test for skeleton unit model.
 """
@@ -73,25 +73,25 @@ class TestSkeletonDefault(object):
             expr=m.fs.skeleton.pressure_out[0] ==
             m.fs.skeleton.pressure_in[0] - 10)
 
+        inlet_dict = \
+            {"flow_mol_comp": m.fs.skeleton.flow_comp_in,
+             "temperature": m.fs.skeleton.temperature_in,
+             "pressure": m.fs.skeleton.pressure_in}
+        outlet_dict = \
+            {"flow_mol_comp": m.fs.skeleton.flow_comp_out,
+             "temperature": m.fs.skeleton.temperature_out,
+             "pressure": m.fs.skeleton.pressure_out}
+
+        m.fs.skeleton.add_ports(
+            name="inlet", member_dict=inlet_dict)
+        m.fs.skeleton.add_ports(
+            name="outlet", member_dict=outlet_dict)
+
         return m
 
     @pytest.mark.unit
     def test_ports(self, skeleton_default):
 
-        inlet_dict = \
-            {"flow_mol_comp": skeleton_default.fs.skeleton.flow_comp_in,
-             "temperature": skeleton_default.fs.skeleton.temperature_in,
-             "pressure": skeleton_default.fs.skeleton.pressure_in}
-        outlet_dict = \
-            {"flow_mol_comp": skeleton_default.fs.skeleton.flow_comp_out,
-             "temperature": skeleton_default.fs.skeleton.temperature_out,
-             "pressure": skeleton_default.fs.skeleton.pressure_out}
-
-        skeleton_default.fs.skeleton.add_ports(
-            name="inlet", member_dict=inlet_dict)
-        skeleton_default.fs.skeleton.add_ports(
-            name="outlet", member_dict=outlet_dict)
-
         # Check inlet port and port members
         assert hasattr(skeleton_default.fs.skeleton, "inlet")
         assert len(skeleton_default.fs.skeleton.inlet.vars) == 3
@@ -213,25 +213,25 @@ class TestSkeletonCustom(object):
             expr=m.fs.skeleton.pressure_out[0] ==
             m.fs.skeleton.pressure_in[0] - 10)
 
+        inlet_dict = \
+            {"flow_mol_comp": m.fs.skeleton.flow_comp_in,
+             "temperature": m.fs.skeleton.temperature_in,
+             "pressure": m.fs.skeleton.pressure_in}
+        outlet_dict = \
+            {"flow_mol_comp": m.fs.skeleton.flow_comp_out,
+             "temperature": m.fs.skeleton.temperature_out,
+             "pressure": m.fs.skeleton.pressure_out}
+
+        m.fs.skeleton.add_ports(
+            name="inlet", member_dict=inlet_dict)
+        m.fs.skeleton.add_ports(
+            name="outlet", member_dict=outlet_dict)
+
         return m
 
     @pytest.mark.unit
     def test_ports(self, skeleton_custom):
 
-        inlet_dict = \
-            {"flow_mol_comp": skeleton_custom.fs.skeleton.flow_comp_in,
-             "temperature": skeleton_custom.fs.skeleton.temperature_in,
-             "pressure": skeleton_custom.fs.skeleton.pressure_in}
-        outlet_dict = \
-            {"flow_mol_comp": skeleton_custom.fs.skeleton.flow_comp_out,
-             "temperature": skeleton_custom.fs.skeleton.temperature_out,
-             "pressure": skeleton_custom.fs.skeleton.pressure_out}
-
-        skeleton_custom.fs.skeleton.add_ports(
-            name="inlet", member_dict=inlet_dict)
-        skeleton_custom.fs.skeleton.add_ports(
-            name="outlet", member_dict=outlet_dict)
-
         # Check inlet port and port members
         assert hasattr(skeleton_custom.fs.skeleton, "inlet")
         assert len(skeleton_custom.fs.skeleton.inlet.vars) == 3
